@@ -30,7 +30,7 @@
  *
  * Each #GDataEntry represents a single object on the online service, such as a playlist, video or calendar entry, and the #GDataFeed
  * represents a collection of similar objects.
- **/
+ */
 
 #include <config.h>
 #include <glib.h>
@@ -78,6 +78,7 @@ struct _GDataFeedPrivate {
 	guint start_index;
 	guint total_results;
 	gchar *rights;
+	gchar *next_page_token;
 };
 
 enum {
@@ -92,7 +93,8 @@ enum {
 	PROP_ITEMS_PER_PAGE,
 	PROP_START_INDEX,
 	PROP_TOTAL_RESULTS,
-	PROP_RIGHTS
+	PROP_RIGHTS,
+	PROP_NEXT_PAGE_TOKEN,
 };
 
 G_DEFINE_TYPE (GDataFeed, gdata_feed, GDATA_TYPE_PARSABLE)
@@ -126,7 +128,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 *
 	 * API reference:
 	 * <ulink type="http" url="http://code.google.com/apis/youtube/2.0/reference.html#youtube_data_api_tag_title">atom:title</ulink>
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_TITLE,
 	                                 g_param_spec_string ("title",
 	                                                      "Title", "The title of the feed.",
@@ -139,7 +141,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 * The subtitle of the feed.
 	 *
 	 * API reference: <ulink type="http" url="http://atomenabled.org/developers/syndication/">atom:subtitle</ulink>
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_SUBTITLE,
 	                                 g_param_spec_string ("subtitle",
 	                                                      "Subtitle", "The subtitle of the feed.",
@@ -152,7 +154,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 * The unique and permanent URN ID for the feed.
 	 *
 	 * API reference: <ulink type="http" url="http://code.google.com/apis/youtube/2.0/reference.html#youtube_data_api_tag_id">atom:id</ulink>
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_ID,
 	                                 g_param_spec_string ("id",
 	                                                      "ID", "The unique and permanent URN ID for the feed.",
@@ -167,7 +169,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 * more information.
 	 *
 	 * Since: 0.2.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_ETAG,
 	                                 g_param_spec_string ("etag",
 	                                                      "ETag", "The unique ETag for this version of the feed.",
@@ -181,7 +183,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 *
 	 * API reference: <ulink type="http" url="http://code.google.com/apis/youtube/2.0/reference.html#youtube_data_api_tag_updated">
 	 * atom:updated</ulink>
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_UPDATED,
 	                                 g_param_spec_int64 ("updated",
 	                                                     "Updated", "The time the feed was last updated.",
@@ -194,7 +196,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 * The URI of a logo for the feed.
 	 *
 	 * API reference: <ulink type="http" url="http://code.google.com/apis/youtube/2.0/reference.html#youtube_data_api_tag_logo">atom:logo</ulink>
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_LOGO,
 	                                 g_param_spec_string ("logo",
 	                                                      "Logo", "The URI of a logo for the feed.",
@@ -210,7 +212,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 * <ulink type="http" url="http://www.atomenabled.org/developers/syndication/atom-format-spec.php#element.icon">atom:icon</ulink>
 	 *
 	 * Since: 0.6.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_ICON,
 	                                 g_param_spec_string ("icon",
 	                                                      "Icon", "The URI of an icon for the feed.",
@@ -224,7 +226,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 *
 	 * API reference: <ulink type="http" url="http://code.google.com/apis/youtube/2.0/reference.html#youtube_data_api_tag_generator">
 	 * atom:generator</ulink>
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_GENERATOR,
 	                                 g_param_spec_object ("generator",
 	                                                      "Generator", "Details of the software used to generate the feed.",
@@ -240,7 +242,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 * url="http://www.atomenabled.org/developers/syndication/atom-format-spec.php#element.rights">Atom specification</ulink>.
 	 *
 	 * Since: 0.7.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_RIGHTS,
 	                                 g_param_spec_string ("rights",
 	                                                      "Rights", "The ownership rights pertaining to the entire feed.",
@@ -255,7 +257,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 * API reference:
 	 * <ulink type="http" url="http://code.google.com/apis/youtube/2.0/reference.html#youtube_data_api_tag_openSearch:itemsPerPage">
 	 * openSearch:itemsPerPage</ulink>
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_ITEMS_PER_PAGE,
 	                                 g_param_spec_uint ("items-per-page",
 	                                                    "Items per page", "The number of items per results page feed.",
@@ -272,7 +274,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 *
 	 * API reference: <ulink type="http" url="http://code.google.com/apis/youtube/2.0/reference.html#youtube_data_api_tag_openSearch:startIndex">
 	 * openSearch:startIndex</ulink>
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_START_INDEX,
 	                                 g_param_spec_uint ("start-index",
 	                                                    "Start index", "The one-based index of the first item in the results feed.",
@@ -290,12 +292,28 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	 * API reference:
 	 * <ulink type="http" url="http://code.google.com/apis/youtube/2.0/reference.html#youtube_data_api_tag_openSearch:totalResults">
 	 * openSearch:totalResults</ulink>
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_TOTAL_RESULTS,
 	                                 g_param_spec_uint ("total-results",
 	                                                    "Total results", "The total number of results in the feed.",
 	                                                    0, 1000000, 0,
 	                                                    G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+
+	/**
+	 * GDataFeed:next-page-token:
+	 *
+	 * The next page token for feeds. Pass this to
+	 * gdata_query_set_page_token() to advance to the next page when
+	 * querying APIs which use page tokens rather than page numbers or
+	 * offsets.
+	 *
+	 * Since: 0.17.7
+	 */
+	g_object_class_install_property (gobject_class, PROP_NEXT_PAGE_TOKEN,
+	                                 g_param_spec_string ("next-page-token",
+	                                                      "Next page token", "The next page token for feeds.",
+	                                                      NULL,
+	                                                      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -354,6 +372,7 @@ gdata_feed_finalize (GObject *object)
 	g_free (priv->logo);
 	g_free (priv->icon);
 	g_free (priv->rights);
+	g_free (priv->next_page_token);
 
 	/* Chain up to the parent class */
 	G_OBJECT_CLASS (gdata_feed_parent_class)->finalize (object);
@@ -401,6 +420,9 @@ gdata_feed_get_property (GObject *object, guint property_id, GValue *value, GPar
 		case PROP_TOTAL_RESULTS:
 			g_value_set_uint (value, priv->total_results);
 			break;
+		case PROP_NEXT_PAGE_TOKEN:
+			g_value_set_string (value, priv->next_page_token);
+			break;
 		default:
 			/* We don't have any other property... */
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -456,9 +478,10 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 				_gdata_feed_call_progress_callback (self, data, entry);
 			_gdata_feed_add_entry (self, entry);
 			g_object_unref (entry);
-		} else if (gdata_parser_string_from_element (node, "title", P_NO_DUPES, &(self->priv->title), &success, error) == TRUE ||
+		} else if (gdata_parser_string_from_element (node, "title", P_DEFAULT | P_NO_DUPES, &(self->priv->title), &success, error) == TRUE ||
 		           gdata_parser_string_from_element (node, "subtitle", P_NO_DUPES, &(self->priv->subtitle), &success, error) == TRUE ||
-		           gdata_parser_string_from_element (node, "id", P_NO_DUPES, &(self->priv->id), &success, error) == TRUE ||
+		           gdata_parser_string_from_element (node, "id", P_REQUIRED | P_NON_EMPTY | P_NO_DUPES,
+		                                             &(self->priv->id), &success, error) == TRUE ||
 		           gdata_parser_string_from_element (node, "logo", P_NO_DUPES, &(self->priv->logo), &success, error) == TRUE ||
 		           gdata_parser_string_from_element (node, "icon", P_NO_DUPES, &(self->priv->icon), &success, error) == TRUE ||
 		           gdata_parser_object_from_element_setter (node, "category", P_REQUIRED, GDATA_TYPE_CATEGORY,
@@ -642,6 +665,8 @@ parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GEr
 		/* Ignore. */
 	} else if (g_strcmp0 (json_reader_get_member_name (reader), "etag") == 0) {
 		GDATA_FEED (parsable)->priv->etag = g_strdup (json_reader_get_string_value (reader));
+	} else if (g_strcmp0 (json_reader_get_member_name (reader), "nextPageToken") == 0) {
+		GDATA_FEED (parsable)->priv->next_page_token = g_strdup (json_reader_get_string_value (reader));
 	} else {
 		return GDATA_PARSABLE_CLASS (gdata_feed_parent_class)->parse_json (parsable, reader, user_data, error);
 	}
@@ -751,7 +776,7 @@ _gdata_feed_new_from_json (GType feed_type, const gchar *json, gint length, GTyp
  * Returns a list of the entries contained in this feed.
  *
  * Return value: (element-type GData.Entry) (transfer none): a #GList of #GDataEntry<!-- -->s
- **/
+ */
 GList *
 gdata_feed_get_entries (GDataFeed *self)
 {
@@ -775,7 +800,7 @@ entry_compare_cb (const GDataEntry *entry, const gchar *id)
  * Return value: (transfer none): the #GDataEntry, or %NULL
  *
  * Since: 0.2.0
- **/
+ */
 GDataEntry *
 gdata_feed_look_up_entry (GDataFeed *self, const gchar *id)
 {
@@ -797,7 +822,7 @@ gdata_feed_look_up_entry (GDataFeed *self, const gchar *id)
  * Returns a list of the categories listed in this feed.
  *
  * Return value: (element-type GData.Category) (transfer none): a #GList of #GDataCategory<!-- -->s
- **/
+ */
 GList *
 gdata_feed_get_categories (GDataFeed *self)
 {
@@ -818,7 +843,7 @@ _gdata_feed_add_category (GDataFeed *self, GDataCategory *category)
  * Returns a list of the links listed in this feed.
  *
  * Return value: (element-type GData.Link) (transfer none): a #GList of #GDataLink<!-- -->s
- **/
+ */
 GList *
 gdata_feed_get_links (GDataFeed *self)
 {
@@ -842,7 +867,7 @@ link_compare_cb (const GDataLink *_link, const gchar *rel)
  * Return value: (transfer none): a #GDataLink, or %NULL if one was not found
  *
  * Since: 0.1.1
- **/
+ */
 GDataLink *
 gdata_feed_look_up_link (GDataFeed *self, const gchar *rel)
 {
@@ -870,7 +895,7 @@ _gdata_feed_add_link (GDataFeed *self, GDataLink *_link)
  * Returns a list of the authors listed in this feed.
  *
  * Return value: (element-type GData.Author) (transfer none): a #GList of #GDataAuthor<!-- -->s
- **/
+ */
 GList *
 gdata_feed_get_authors (GDataFeed *self)
 {
@@ -891,7 +916,7 @@ _gdata_feed_add_author (GDataFeed *self, GDataAuthor *author)
  * Returns the title of the feed.
  *
  * Return value: the feed's title
- **/
+ */
 const gchar *
 gdata_feed_get_title (GDataFeed *self)
 {
@@ -906,7 +931,7 @@ gdata_feed_get_title (GDataFeed *self)
  * Returns the subtitle of the feed.
  *
  * Return value: the feed's subtitle, or %NULL
- **/
+ */
 const gchar *
 gdata_feed_get_subtitle (GDataFeed *self)
 {
@@ -921,7 +946,7 @@ gdata_feed_get_subtitle (GDataFeed *self)
  * Returns the feed's unique and permanent URN ID.
  *
  * Return value: the feed's ID
- **/
+ */
 const gchar *
 gdata_feed_get_id (GDataFeed *self)
 {
@@ -938,7 +963,7 @@ gdata_feed_get_id (GDataFeed *self)
  * Return value: the feed's ETag
  *
  * Since: 0.2.0
- **/
+ */
 const gchar *
 gdata_feed_get_etag (GDataFeed *self)
 {
@@ -953,7 +978,7 @@ gdata_feed_get_etag (GDataFeed *self)
  * Gets the time the feed was last updated.
  *
  * Return value: the UNIX timestamp for the time the feed was last updated
- **/
+ */
 gint64
 gdata_feed_get_updated (GDataFeed *self)
 {
@@ -968,7 +993,7 @@ gdata_feed_get_updated (GDataFeed *self)
  * Returns the logo URI of the feed.
  *
  * Return value: the feed's logo URI, or %NULL
- **/
+ */
 const gchar *
 gdata_feed_get_logo (GDataFeed *self)
 {
@@ -985,7 +1010,7 @@ gdata_feed_get_logo (GDataFeed *self)
  * Return value: the feed's icon URI, or %NULL
  *
  * Since: 0.6.0
- **/
+ */
 const gchar *
 gdata_feed_get_icon (GDataFeed *self)
 {
@@ -1000,7 +1025,7 @@ gdata_feed_get_icon (GDataFeed *self)
  * Returns details about the software which generated the feed.
  *
  * Return value: (transfer none): a #GDataGenerator, or %NULL
- **/
+ */
 GDataGenerator *
 gdata_feed_get_generator (GDataFeed *self)
 {
@@ -1017,7 +1042,7 @@ gdata_feed_get_generator (GDataFeed *self)
  * Return value: the feed's rights information
  *
  * Since: 0.7.0
- **/
+ */
 const gchar *
 gdata_feed_get_rights (GDataFeed *self)
 {
@@ -1032,7 +1057,7 @@ gdata_feed_get_rights (GDataFeed *self)
  * Returns the number of items per results page feed.
  *
  * Return value: the number of items per results page feed, or <code class="literal">0</code>
- **/
+ */
 guint
 gdata_feed_get_items_per_page (GDataFeed *self)
 {
@@ -1047,7 +1072,7 @@ gdata_feed_get_items_per_page (GDataFeed *self)
  * Returns the one-based start index of the results feed in the result set.
  *
  * Return value: the one-based start index, or <code class="literal">0</code>
- **/
+ */
 guint
 gdata_feed_get_start_index (GDataFeed *self)
 {
@@ -1063,7 +1088,7 @@ gdata_feed_get_start_index (GDataFeed *self)
  * pages. If this is zero, the total number is unknown.
  *
  * Return value: the total number of results, or <code class="literal">0</code>
- **/
+ */
 guint
 gdata_feed_get_total_results (GDataFeed *self)
 {
@@ -1071,6 +1096,27 @@ gdata_feed_get_total_results (GDataFeed *self)
 	return self->priv->total_results;
 }
 
+/**
+ * gdata_feed_get_next_page_token:
+ * @self: a #GDataFeed
+ *
+ * Returns the next page token for a query result, or %NULL if not set.
+ * This is #GDataFeed:next-page-token. The page token might not be set if there
+ * is no next page, or if this service does not use token based paging (for
+ * example, if it uses page number or offset based paging instead). Most more
+ * recent services use token based paging.
+ *
+ * Return value: (nullable): the next page token
+ *
+ * Since: 0.17.7
+ */
+const gchar *
+gdata_feed_get_next_page_token (GDataFeed *self)
+{
+	g_return_val_if_fail (GDATA_IS_FEED (self), NULL);
+	return self->priv->next_page_token;
+}
+
 void
 _gdata_feed_add_entry (GDataFeed *self, GDataEntry *entry)
 {
