@@ -20,12 +20,13 @@
 /**
  * SECTION:gdata-oauth1-authorizer
  * @short_description: GData OAuth 1.0 authorization interface
- * @stability: Unstable
+ * @stability: Stable
  * @include: gdata/gdata-oauth1-authorizer.h
  *
  * #GDataOAuth1Authorizer provides an implementation of the #GDataAuthorizer interface for authentication and authorization using the
- * <ulink type="http" url="http://code.google.com/apis/accounts/docs/OAuthForInstalledApps.html">OAuth 1.0</ulink> process, which is Google's
- * currently preferred authentication and authorization process, though OAuth 2.0 will be transitioned to in future.
+ * <ulink type="http" url="http://code.google.com/apis/accounts/docs/OAuthForInstalledApps.html">OAuth 1.0</ulink> process,
+ * which was preferred by Google until OAuth 2.0 was released — it is now
+ * preferred to use #GDataOAuth2Authorizer.
  *
  * OAuth 1.0 replaces the deprecated ClientLogin process. One of the main reasons for this is to allow two-factor authentication to be supported, by
  * moving the authentication interface to a web page under Google's control.
@@ -249,7 +250,7 @@ gdata_oauth1_authorizer_class_init (GDataOAuth1AuthorizerClass *klass)
 	 * The proxy URI used internally for all network requests.
 	 *
 	 * Since: 0.9.0
-	 * Deprecated: Use #GDataClientLoginAuthorizer:proxy-resolver instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
+	 * Deprecated: 0.15.0: Use #GDataClientLoginAuthorizer:proxy-resolver instead, which gives more flexibility over the proxy used.
 	 */
 	g_object_class_install_property (gobject_class, PROP_PROXY_URI,
 	                                 g_param_spec_boxed ("proxy-uri",
@@ -880,21 +881,23 @@ request_authentication_uri_async_data_free (RequestAuthenticationUriAsyncData *d
 	g_slice_free (RequestAuthenticationUriAsyncData, data);
 }
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (RequestAuthenticationUriAsyncData, request_authentication_uri_async_data_free)
+
 static void
-request_authentication_uri_thread (GSimpleAsyncResult *result, GDataOAuth1Authorizer *authorizer, GCancellable *cancellable)
+request_authentication_uri_thread (GTask *task, gpointer source_object, gpointer task_data, GCancellable *cancellable)
 {
-	RequestAuthenticationUriAsyncData *data;
-	GError *error = NULL;
-
-	data = g_simple_async_result_get_op_res_gpointer (result);
+	GDataOAuth1Authorizer *authorizer = GDATA_OAUTH1_AUTHORIZER (source_object);
+	g_autoptr(RequestAuthenticationUriAsyncData) data = NULL;
+	g_autoptr(GError) error = NULL;
 
+	data = g_slice_new0 (RequestAuthenticationUriAsyncData);
 	data->authentication_uri = gdata_oauth1_authorizer_request_authentication_uri (authorizer, &(data->token), &(data->token_secret),
 	                                                                               cancellable, &error);
 
-	if (error != NULL) {
-		g_simple_async_result_set_from_error (result, error);
-		g_error_free (error);
-	}
+	if (error != NULL)
+		g_task_return_error (task, g_steal_pointer (&error));
+	else
+		g_task_return_pointer (task, g_steal_pointer (&data), (GDestroyNotify) request_authentication_uri_async_data_free);
 }
 
 /**
@@ -918,22 +921,15 @@ void
 gdata_oauth1_authorizer_request_authentication_uri_async (GDataOAuth1Authorizer *self, GCancellable *cancellable,
                                                           GAsyncReadyCallback callback, gpointer user_data)
 {
-	GSimpleAsyncResult *result;
-	RequestAuthenticationUriAsyncData *data;
+	g_autoptr(GTask) task = NULL;
 
 	g_return_if_fail (GDATA_IS_OAUTH1_AUTHORIZER (self));
 	g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
 	g_return_if_fail (callback != NULL);
 
-	data = g_slice_new (RequestAuthenticationUriAsyncData);
-	data->token = NULL;
-	data->token_secret = NULL;
-	data->authentication_uri = NULL;
-
-	result = g_simple_async_result_new (G_OBJECT (self), callback, user_data, gdata_oauth1_authorizer_request_authentication_uri_async);
-	g_simple_async_result_set_op_res_gpointer (result, data, (GDestroyNotify) request_authentication_uri_async_data_free);
-	g_simple_async_result_run_in_thread (result, (GSimpleAsyncThreadFunc) request_authentication_uri_thread, G_PRIORITY_DEFAULT, cancellable);
-	g_object_unref (result);
+	task = g_task_new (self, cancellable, callback, user_data);
+	g_task_set_source_tag (task, gdata_oauth1_authorizer_request_authentication_uri_async);
+	g_task_run_in_thread (task, request_authentication_uri_thread);
 }
 
 /**
@@ -967,18 +963,19 @@ gchar *
 gdata_oauth1_authorizer_request_authentication_uri_finish (GDataOAuth1Authorizer *self, GAsyncResult *async_result, gchar **token,
                                                            gchar **token_secret, GError **error)
 {
-	RequestAuthenticationUriAsyncData *data;
-	gchar *authentication_uri;
+	g_autoptr(RequestAuthenticationUriAsyncData) data = NULL;
 
-	g_return_val_if_fail (GDATA_IS_OAUTH1_AUTHORIZER (self), FALSE);
-	g_return_val_if_fail (G_IS_ASYNC_RESULT (async_result), FALSE);
+	g_return_val_if_fail (GDATA_IS_OAUTH1_AUTHORIZER (self), NULL);
+	g_return_val_if_fail (G_IS_ASYNC_RESULT (async_result), NULL);
 	g_return_val_if_fail (token != NULL, NULL);
 	g_return_val_if_fail (token_secret != NULL, NULL);
-	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+	g_return_val_if_fail (g_task_is_valid (async_result, self), NULL);
+	g_return_val_if_fail (g_async_result_is_tagged (async_result, gdata_oauth1_authorizer_request_authentication_uri_async), NULL);
 
-	g_warn_if_fail (g_simple_async_result_is_valid (async_result, G_OBJECT (self), gdata_oauth1_authorizer_request_authentication_uri_async));
+	data = g_task_propagate_pointer (G_TASK (async_result), error);
 
-	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (async_result), error) == TRUE) {
+	if (data == NULL) {
 		/* Return the error and set all of the output parameters to NULL */
 		*token = NULL;
 		*token_secret = NULL;
@@ -987,17 +984,10 @@ gdata_oauth1_authorizer_request_authentication_uri_finish (GDataOAuth1Authorizer
 	}
 
 	/* Success! Transfer the output to the appropriate parameters and nullify it so it doesn't get freed when the async result gets finalised */
-	data = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (async_result));
+	*token = g_steal_pointer (&data->token);
+	*token_secret = g_steal_pointer (&data->token_secret);
 
-	*token = data->token;
-	*token_secret = data->token_secret;
-	authentication_uri = data->authentication_uri;
-
-	data->token = NULL;
-	data->token_secret = NULL;
-	data->authentication_uri = NULL;
-
-	return authentication_uri;
+	return g_steal_pointer (&data->authentication_uri);
 }
 
 /**
@@ -1155,21 +1145,16 @@ request_authorization_async_data_free (RequestAuthorizationAsyncData *data)
 }
 
 static void
-request_authorization_thread (GSimpleAsyncResult *result, GDataOAuth1Authorizer *authorizer, GCancellable *cancellable)
+request_authorization_thread (GTask *task, gpointer source_object, gpointer task_data, GCancellable *cancellable)
 {
-	RequestAuthorizationAsyncData *data;
-	gboolean success;
-	GError *error = NULL;
+	GDataOAuth1Authorizer *authorizer = GDATA_OAUTH1_AUTHORIZER (source_object);
+	RequestAuthorizationAsyncData *data = task_data;
+	g_autoptr(GError) error = NULL;
 
-	data = g_simple_async_result_get_op_res_gpointer (result);
-
-	success = gdata_oauth1_authorizer_request_authorization (authorizer, data->token, data->token_secret, data->verifier, cancellable, &error);
-	g_simple_async_result_set_op_res_gboolean (result, success);
-
-	if (error != NULL) {
-		g_simple_async_result_set_from_error (result, error);
-		g_error_free (error);
-	}
+	if (!gdata_oauth1_authorizer_request_authorization (authorizer, data->token, data->token_secret, data->verifier, cancellable, &error))
+		g_task_return_error (task, g_steal_pointer (&error));
+	else
+		g_task_return_boolean (task, TRUE);
 }
 
 /**
@@ -1197,7 +1182,7 @@ gdata_oauth1_authorizer_request_authorization_async (GDataOAuth1Authorizer *self
                                                      const gchar *verifier,
                                                      GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-	GSimpleAsyncResult *result;
+	g_autoptr(GTask) task = NULL;
 	RequestAuthorizationAsyncData *data;
 
 	g_return_if_fail (GDATA_IS_OAUTH1_AUTHORIZER (self));
@@ -1211,10 +1196,10 @@ gdata_oauth1_authorizer_request_authorization_async (GDataOAuth1Authorizer *self
 	data->token_secret = _gdata_service_secure_strdup (token_secret);
 	data->verifier = g_strdup (verifier);
 
-	result = g_simple_async_result_new (G_OBJECT (self), callback, user_data, gdata_oauth1_authorizer_request_authorization_async);
-	g_simple_async_result_set_op_res_gpointer (result, data, (GDestroyNotify) request_authorization_async_data_free);
-	g_simple_async_result_run_in_thread (result, (GSimpleAsyncThreadFunc) request_authorization_thread, G_PRIORITY_DEFAULT, cancellable);
-	g_object_unref (result);
+	task = g_task_new (self, cancellable, callback, user_data);
+	g_task_set_source_tag (task, gdata_oauth1_authorizer_request_authorization_async);
+	g_task_set_task_data (task, g_steal_pointer (&data), (GDestroyNotify) request_authorization_async_data_free);
+	g_task_run_in_thread (task, request_authorization_thread);
 }
 
 /**
@@ -1235,14 +1220,10 @@ gdata_oauth1_authorizer_request_authorization_finish (GDataOAuth1Authorizer *sel
 	g_return_val_if_fail (GDATA_IS_OAUTH1_AUTHORIZER (self), FALSE);
 	g_return_val_if_fail (G_IS_ASYNC_RESULT (async_result), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+	g_return_val_if_fail (g_task_is_valid (async_result, self), FALSE);
+	g_return_val_if_fail (g_async_result_is_tagged (async_result, gdata_oauth1_authorizer_request_authorization_async), FALSE);
 
-	g_warn_if_fail (g_simple_async_result_is_valid (async_result, G_OBJECT (self), gdata_oauth1_authorizer_request_authorization_async));
-
-	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (async_result), error) == TRUE) {
-		return FALSE;
-	}
-
-	return TRUE;
+	return g_task_propagate_boolean (G_TASK (async_result), error);
 }
 
 /**
@@ -1350,7 +1331,7 @@ _get_proxy_uri (GDataOAuth1Authorizer *self)
  * Return value: (transfer full) (allow-none): the proxy URI, or %NULL; free with soup_uri_free()
  *
  * Since: 0.9.0
- * Deprecated: Use gdata_oauth1_authorizer_get_proxy_resolver() instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
+ * Deprecated: 0.15.0: Use gdata_oauth1_authorizer_get_proxy_resolver() instead, which gives more flexibility over the proxy used.
  */
 SoupURI *
 gdata_oauth1_authorizer_get_proxy_uri (GDataOAuth1Authorizer *self)
@@ -1379,7 +1360,7 @@ _set_proxy_uri (GDataOAuth1Authorizer *self, SoupURI *proxy_uri)
  * If @proxy_uri is %NULL, no proxy will be used.
  *
  * Since: 0.9.0
- * Deprecated: Use gdata_oauth1_authorizer_set_proxy_resolver() instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
+ * Deprecated: 0.15.0: Use gdata_oauth1_authorizer_set_proxy_resolver() instead, which gives more flexibility over the proxy used.
  */
 void
 gdata_oauth1_authorizer_set_proxy_uri (GDataOAuth1Authorizer *self, SoupURI *proxy_uri)
