@@ -81,8 +81,8 @@ gdata_parser_error_not_iso8601_format (xmlNode *element, const gchar *actual_val
 	              * and the second parameter is the erroneous value (which was not in ISO 8601 format).
 	              *
 	              * For example:
-	              *  The content of a <media:group/media:uploaded> element ("2009-05-06 26:30Z") was not in ISO 8601 format. */
-	             _("The content of a %s element (\"%s\") was not in ISO 8601 format."), element_string, actual_value);
+	              *  The content of a <media:group/media:uploaded> element (‘2009-05-06 26:30Z’) was not in ISO 8601 format. */
+	             _("The content of a %s element (‘%s’) was not in ISO 8601 format."), element_string, actual_value);
 	g_free (element_string);
 
 	return FALSE;
@@ -101,8 +101,8 @@ gdata_parser_error_unknown_property_value (xmlNode *element, const gchar *proper
 	              * (including the angle brackets ("<" and ">")) to which the property belongs, and the third is the unknown value.
 	              *
 	              * For example:
-	              *  The value of the @time property of a <media:group/media:thumbnail> element ("00:01:42.500") was unknown. */
-	             _("The value of the %s property of a %s element (\"%s\") was unknown."), property_string, element_string, actual_value);
+	              *  The value of the @time property of a <media:group/media:thumbnail> element (‘00:01:42.500’) was unknown. */
+	             _("The value of the %s property of a %s element (‘%s’) was unknown."), property_string, element_string, actual_value);
 	g_free (property_string);
 	g_free (element_string);
 
@@ -119,8 +119,8 @@ gdata_parser_error_unknown_content (xmlNode *element, const gchar *actual_conten
 	              * and the second parameter is the unknown content of that element.
 	              *
 	              * For example:
-	              *  The content of a <gphoto:access> element ("protected") was unknown. */
-	             _("The content of a %s element (\"%s\") was unknown."), element_string, actual_content);
+	              *  The content of a <gphoto:access> element (‘protected’) was unknown. */
+	             _("The content of a %s element (‘%s’) was unknown."), element_string, actual_content);
 	g_free (element_string);
 
 	return FALSE;
@@ -248,6 +248,37 @@ gdata_parser_int64_to_iso8601 (gint64 _time)
 	return g_time_val_to_iso8601 (&time_val);
 }
 
+gchar *
+gdata_parser_int64_to_iso8601_numeric_timezone (gint64 _time)
+{
+	GTimeVal time_val;
+	gchar *iso8601;
+	gchar **date_time_components;
+	gchar *retval;
+
+	time_val.tv_sec = _time;
+	time_val.tv_usec = 0;
+
+	iso8601 = g_time_val_to_iso8601 (&time_val);
+
+	/* FIXME: Work around for Google's incorrect ISO 8601 implementation.
+	 * They appear to not like dates in the format ‘2014-08-09T21:07:05Z’
+	 * which specify a timezone using ‘Z’ and no microseconds. This varies
+	 * between services.
+	 *
+	 * See: https://bugzilla.gnome.org/show_bug.cgi?id=732809
+	 * https://bugzilla.gnome.org/show_bug.cgi?id=780067
+	 * https://code.google.com/a/google.com/p/apps-api-issues/issues/detail?id=3595
+	 * http://stackoverflow.com/a/17630320/2931197 */
+	date_time_components = g_strsplit (iso8601, "Z", 2);
+	retval = g_strjoinv (".000001+00:00", date_time_components);
+	g_strfreev (date_time_components);
+
+	g_free (iso8601);
+
+	return retval;
+}
+
 gboolean
 gdata_parser_int64_from_iso8601 (const gchar *date, gint64 *_time)
 {
@@ -269,8 +300,8 @@ gdata_parser_error_required_json_content_missing (JsonReader *reader, GError **e
 	/* Translators: the parameter is the name of an JSON element.
 	 *
 	 * For example:
-	 *  A 'title' element was missing required content. */
-	g_set_error (error, GDATA_SERVICE_ERROR, GDATA_SERVICE_ERROR_PROTOCOL_ERROR, _("A \'%s\' element was missing required content."), element_string);
+	 *  A ‘title’ element was missing required content. */
+	g_set_error (error, GDATA_SERVICE_ERROR, GDATA_SERVICE_ERROR_PROTOCOL_ERROR, _("A ‘%s’ element was missing required content."), element_string);
 
 	return FALSE;
 }
@@ -299,8 +330,8 @@ gdata_parser_error_not_iso8601_format_json (JsonReader *reader, const gchar *act
 	              * and the second parameter is the erroneous value (which was not in ISO 8601 format).
 	              *
 	              * For example:
-	              *  The content of a 'uploaded' element ("2009-05-06 26:30Z") was not in ISO 8601 format. */
-	             _("The content of a \'%s\' element (\"%s\") was not in ISO 8601 format."), element_string, actual_value);
+	              *  The content of a ‘uploaded’ element (‘2009-05-06 26:30Z’) was not in ISO 8601 format. */
+	             _("The content of a ‘%s’ element (‘%s’) was not in ISO 8601 format."), element_string, actual_value);
 
 	return FALSE;
 }
@@ -1175,8 +1206,8 @@ gdata_parser_color_from_json_member (JsonReader *reader,
 		              * RGB format).
 		              *
 		              * For example:
-		              *  The content of a <entry/gCal:color> element ("00FG56") was not in hexadecimal RGB format. */
-		             _("The content of a %s element (\"%s\") was not in hexadecimal RGB format."),
+		              *  The content of a <entry/gCal:color> element (‘00FG56’) was not in hexadecimal RGB format. */
+		             _("The content of a %s element (‘%s’) was not in hexadecimal RGB format."),
 		             member_name, text);
 		*success = FALSE;
 
