@@ -39,7 +39,7 @@ G_BEGIN_DECLS
  * logs, and don't redact usernames, passwords and auth. tokens
  *
  * Logging level.
- **/
+ */
 typedef enum {
 	GDATA_LOG_NONE = 0,
 	GDATA_LOG_MESSAGES = 1,
@@ -71,13 +71,21 @@ G_GNUC_INTERNAL GDataSecureString _gdata_service_secure_strndup (const gchar *st
 G_GNUC_INTERNAL void _gdata_service_secure_strfree (GDataSecureString str);
 
 #include "gdata-query.h"
+typedef enum {
+	GDATA_QUERY_PAGINATION_INDEXED,
+	GDATA_QUERY_PAGINATION_URIS,
+	GDATA_QUERY_PAGINATION_TOKENS,
+} GDataQueryPaginationType;
+
 G_GNUC_INTERNAL void _gdata_query_add_q_internal (GDataQuery *self, const gchar *q);
 G_GNUC_INTERNAL void _gdata_query_clear_q_internal (GDataQuery *self);
+G_GNUC_INTERNAL void _gdata_query_clear_pagination (GDataQuery *self);
+G_GNUC_INTERNAL void _gdata_query_set_pagination_type (GDataQuery               *self,
+                                                       GDataQueryPaginationType  type);
+G_GNUC_INTERNAL void _gdata_query_set_next_page_token (GDataQuery  *self, const gchar *next_page_token);
 G_GNUC_INTERNAL void _gdata_query_set_next_uri (GDataQuery *self, const gchar *next_uri);
-G_GNUC_INTERNAL void _gdata_query_set_next_uri_end (GDataQuery *self);
 G_GNUC_INTERNAL gboolean _gdata_query_is_finished (GDataQuery *self);
 G_GNUC_INTERNAL void _gdata_query_set_previous_uri (GDataQuery *self, const gchar *previous_uri);
-G_GNUC_INTERNAL void _gdata_query_set_previous_uri_end (GDataQuery *self);
 
 #include "gdata-parsable.h"
 G_GNUC_INTERNAL GDataParsable *_gdata_parsable_new_from_xml (GType parsable_type, const gchar *xml, gint length, gpointer user_data,
