@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * GData Client
- * Copyright (C) Philip Withnall 2008–2010 <philip@tecnocode.co.uk>
+ * Copyright (C) Philip Withnall 2008, 2009, 2010, 2014 <philip@tecnocode.co.uk>
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
 /**
  * SECTION:gdata-service
  * @short_description: GData service object
- * @stability: Unstable
+ * @stability: Stable
  * @include: gdata/gdata-service.h
  *
  * #GDataService represents a GData API service, typically a website using the GData API, such as YouTube or Google Calendar. One
@@ -68,6 +68,16 @@ static void gdata_service_set_property (GObject *object, guint property_id, cons
 static void real_append_query_headers (GDataService *self, GDataAuthorizationDomain *domain, SoupMessage *message);
 static void real_parse_error_response (GDataService *self, GDataOperationType operation_type, guint status, const gchar *reason_phrase,
                                        const gchar *response_body, gint length, GError **error);
+static GDataFeed *
+real_parse_feed (GDataService *self,
+                 GDataAuthorizationDomain *domain,
+                 GDataQuery *query,
+                 GType entry_type,
+                 SoupMessage *message,
+                 GCancellable *cancellable,
+                 GDataQueryProgressCallback progress_callback,
+                 gpointer progress_user_data,
+                 GError **error);
 static void notify_proxy_uri_cb (GObject *gobject, GParamSpec *pspec, GObject *self);
 static void notify_timeout_cb (GObject *gobject, GParamSpec *pspec, GObject *self);
 static void debug_handler (const char *log_domain, GLogLevelFlags log_level, const char *message, gpointer user_data);
@@ -75,7 +85,7 @@ static void soup_log_printer (SoupLogger *logger, SoupLoggerLogLevel level, char
 
 static GDataFeed *__gdata_service_query (GDataService *self, GDataAuthorizationDomain *domain, const gchar *feed_uri, GDataQuery *query,
                                          GType entry_type, GCancellable *cancellable, GDataQueryProgressCallback progress_callback,
-                                         gpointer progress_user_data, GError **error, gboolean is_async);
+                                         gpointer progress_user_data, GError **error);
 
 static SoupURI *_get_proxy_uri (GDataService *self);
 static void _set_proxy_uri (GDataService *self, SoupURI *proxy_uri);
@@ -113,6 +123,7 @@ gdata_service_class_init (GDataServiceClass *klass)
 	klass->feed_type = GDATA_TYPE_FEED;
 	klass->append_query_headers = real_append_query_headers;
 	klass->parse_error_response = real_parse_error_response;
+	klass->parse_feed = real_parse_feed;
 	klass->get_authorization_domains = NULL; /* equivalent to returning an empty list of domains */
 
 	/**
@@ -123,8 +134,8 @@ gdata_service_class_init (GDataServiceClass *klass)
 	 * Note that if a #GDataAuthorizer is being used with this #GDataService, the authorizer might also need its proxy URI setting.
 	 *
 	 * Since: 0.2.0
-	 * Deprecated: Use #GDataService:proxy-resolver instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
-	 **/
+	 * Deprecated: 0.15.0: Use #GDataService:proxy-resolver instead, which gives more flexibility over the proxy used.
+	 */
 	g_object_class_install_property (gobject_class, PROP_PROXY_URI,
 	                                 g_param_spec_boxed ("proxy-uri",
 	                                                     "Proxy URI", "The proxy URI used internally for all network requests.",
@@ -142,7 +153,7 @@ gdata_service_class_init (GDataServiceClass *klass)
 	 * Note that if a #GDataAuthorizer is being used with this #GDataService, the authorizer might also need its timeout setting.
 	 *
 	 * Since: 0.7.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_TIMEOUT,
 	                                 g_param_spec_uint ("timeout",
 	                                                    "Timeout", "A timeout, in seconds, for network operations.",
@@ -161,7 +172,7 @@ gdata_service_class_init (GDataServiceClass *klass)
 	 * The server-side behaviour is undefined if it doesn't support a given locale.
 	 *
 	 * Since: 0.7.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_LOCALE,
 	                                 g_param_spec_string ("locale",
 	                                                      "Locale", "The locale to use for network requests, in Unix locale format.",
@@ -185,7 +196,7 @@ gdata_service_class_init (GDataServiceClass *klass)
 	 * video to YouTube does. It's an unnecessary overhead to require the user to authorize against a service when not strictly required.
 	 *
 	 * Since: 0.9.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_AUTHORIZER,
 	                                 g_param_spec_object ("authorizer",
 	                                                      "Authorizer", "An authorizer object to provide an authorization token for each request.",
@@ -347,7 +358,7 @@ real_parse_error_response (GDataService *self, GDataOperationType operation_type
 		case SOUP_STATUS_SSL_FAILED:
 		case SOUP_STATUS_IO_ERROR:
 			g_set_error (error, GDATA_SERVICE_ERROR, GDATA_SERVICE_ERROR_NETWORK_ERROR,
-			             _("Cannot connect to the service's server."));
+			             _("Cannot connect to the service’s server."));
 			return;
 		case SOUP_STATUS_CANT_RESOLVE_PROXY:
 		case SOUP_STATUS_CANT_CONNECT_PROXY:
@@ -570,9 +581,11 @@ _gdata_service_build_message (GDataService *self, GDataAuthorizationDomain *doma
 	GDataServiceClass *klass;
 	SoupURI *_uri;
 
-	/* Create the message. Allow changing the HTTPS port just for testing. */
+	/* Create the message. Allow changing the HTTPS port just for testing,
+	 * but require that the URI is always HTTPS for privacy. */
 	_uri = soup_uri_new (uri);
 	soup_uri_set_port (_uri, _gdata_service_get_https_port ());
+	g_assert_cmpstr (soup_uri_get_scheme (_uri), ==, SOUP_URI_SCHEME_HTTPS);
 	message = soup_message_new_from_uri (method, _uri);
 	soup_uri_free (_uri);
 
@@ -774,7 +787,6 @@ typedef struct {
 	GType entry_type;
 
 	/* Output */
-	GDataFeed *feed;
 	GDataQueryProgressCallback progress_callback;
 	gpointer progress_user_data;
 	GDestroyNotify destroy_progress_user_data;
@@ -789,25 +801,25 @@ query_async_data_free (QueryAsyncData *self)
 	g_free (self->feed_uri);
 	if (self->query)
 		g_object_unref (self->query);
-	if (self->feed)
-		g_object_unref (self->feed);
 
 	g_slice_free (QueryAsyncData, self);
 }
 
 static void
-query_thread (GSimpleAsyncResult *result, GDataService *service, GCancellable *cancellable)
+query_thread (GTask *task, gpointer source_object, gpointer task_data, GCancellable *cancellable)
 {
-	GError *error = NULL;
-	QueryAsyncData *data = g_simple_async_result_get_op_res_gpointer (result);
+	GDataService *service = GDATA_SERVICE (source_object);
+	g_autoptr(GError) error = NULL;
+	QueryAsyncData *data = task_data;
+	g_autoptr(GDataFeed) feed = NULL;
 
 	/* Execute the query and return */
-	data->feed = __gdata_service_query (service, data->domain, data->feed_uri, data->query, data->entry_type, cancellable,
-	                                    data->progress_callback, data->progress_user_data, &error, TRUE);
-	if (data->feed == NULL && error != NULL) {
-		g_simple_async_result_set_from_error (result, error);
-		g_error_free (error);
-	}
+	feed = __gdata_service_query (service, data->domain, data->feed_uri, data->query, data->entry_type, cancellable,
+	                              data->progress_callback, data->progress_user_data, &error);
+	if (feed == NULL && error != NULL)
+		g_task_return_error (task, g_steal_pointer (&error));
+	else
+		g_task_return_pointer (task, g_steal_pointer (&feed), g_object_unref);
 
 	if (data->destroy_progress_user_data != NULL) {
 		data->destroy_progress_user_data (data->progress_user_data);
@@ -838,13 +850,13 @@ query_thread (GSimpleAsyncResult *result, GDataService *service, GCancellable *c
  * to get the results of the operation.
  *
  * Since: 0.9.1
- **/
+ */
 void
 gdata_service_query_async (GDataService *self, GDataAuthorizationDomain *domain, const gchar *feed_uri, GDataQuery *query, GType entry_type,
                            GCancellable *cancellable, GDataQueryProgressCallback progress_callback, gpointer progress_user_data,
                            GDestroyNotify destroy_progress_user_data, GAsyncReadyCallback callback, gpointer user_data)
 {
-	GSimpleAsyncResult *result;
+	g_autoptr(GTask) task = NULL;
 	QueryAsyncData *data;
 
 	g_return_if_fail (GDATA_IS_SERVICE (self));
@@ -859,15 +871,14 @@ gdata_service_query_async (GDataService *self, GDataAuthorizationDomain *domain,
 	data->feed_uri = g_strdup (feed_uri);
 	data->query = (query != NULL) ? g_object_ref (query) : NULL;
 	data->entry_type = entry_type;
-	data->feed = NULL;
 	data->progress_callback = progress_callback;
 	data->progress_user_data = progress_user_data;
 	data->destroy_progress_user_data = destroy_progress_user_data;
 
-	result = g_simple_async_result_new (G_OBJECT (self), callback, user_data, gdata_service_query_async);
-	g_simple_async_result_set_op_res_gpointer (result, data, (GDestroyNotify) query_async_data_free);
-	g_simple_async_result_run_in_thread (result, (GSimpleAsyncThreadFunc) query_thread, G_PRIORITY_DEFAULT, cancellable);
-	g_object_unref (result);
+	task = g_task_new (self, cancellable, callback, user_data);
+	g_task_set_source_tag (task, gdata_service_query_async);
+	g_task_set_task_data (task, g_steal_pointer (&data), (GDestroyNotify) query_async_data_free);
+	g_task_run_in_thread (task, query_thread);
 }
 
 /**
@@ -879,26 +890,17 @@ gdata_service_query_async (GDataService *self, GDataAuthorizationDomain *domain,
  * Finishes an asynchronous query operation started with gdata_service_query_async().
  *
  * Return value: (transfer full): a #GDataFeed of query results, or %NULL; unref with g_object_unref()
- **/
+ */
 GDataFeed *
 gdata_service_query_finish (GDataService *self, GAsyncResult *async_result, GError **error)
 {
-	GSimpleAsyncResult *result = G_SIMPLE_ASYNC_RESULT (async_result);
-	QueryAsyncData *data;
-
 	g_return_val_if_fail (GDATA_IS_SERVICE (self), NULL);
 	g_return_val_if_fail (G_IS_ASYNC_RESULT (async_result), NULL);
-	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+	g_return_val_if_fail (g_task_is_valid (async_result, self), NULL);
+	g_return_val_if_fail (g_async_result_is_tagged (async_result, gdata_service_query_async), NULL);
 
-	g_warn_if_fail (g_simple_async_result_get_source_tag (result) == gdata_service_query_async);
-
-	if (g_simple_async_result_propagate_error (result, error) == TRUE)
-		return NULL;
-
-	data = g_simple_async_result_get_op_res_gpointer (result);
-	if (data->feed != NULL)
-		return g_object_ref (data->feed);
-	return NULL;
+	return g_task_propagate_pointer (G_TASK (async_result), error);
 }
 
 /* Does the bulk of the work of gdata_service_query. Split out because certain queries (such as that done by
@@ -946,22 +948,59 @@ _gdata_service_query (GDataService *self, GDataAuthorizationDomain *domain, cons
 
 static GDataFeed *
 __gdata_service_query (GDataService *self, GDataAuthorizationDomain *domain, const gchar *feed_uri, GDataQuery *query, GType entry_type,
-                       GCancellable *cancellable, GDataQueryProgressCallback progress_callback, gpointer progress_user_data, GError **error,
-                       gboolean is_async)
+                       GCancellable *cancellable, GDataQueryProgressCallback progress_callback, gpointer progress_user_data, GError **error)
 {
 	GDataServiceClass *klass;
-	GDataFeed *feed = NULL;
 	SoupMessage *message;
-	SoupMessageHeaders *headers;
-	const gchar *content_type;
+	GDataFeed *feed;
 
+	klass = GDATA_SERVICE_GET_CLASS (self);
+
+	/* Are we off the end of the final page? */
+	if (query != NULL && _gdata_query_is_finished (query)) {
+		GTimeVal updated;
+
+		/* Build an empty dummy feed to signify the end of the list. */
+		g_get_current_time (&updated);
+		return _gdata_feed_new (klass->feed_type, "Empty feed", "feed1",
+		                        updated.tv_sec);
+	}
+
+	/* Send the request. */
 	message = _gdata_service_query (self, domain, feed_uri, query, cancellable, error);
 	if (message == NULL)
 		return NULL;
 
 	g_assert (message->response_body->data != NULL);
-	klass = GDATA_SERVICE_GET_CLASS (self);
+	g_assert (klass->parse_feed != NULL);
 
+	/* Parse the response. */
+	feed = klass->parse_feed (self, domain, query, entry_type,
+	                          message, cancellable, progress_callback,
+	                          progress_user_data, error);
+
+	g_object_unref (message);
+
+	return feed;
+}
+
+static GDataFeed *
+real_parse_feed (GDataService *self,
+                 GDataAuthorizationDomain *domain,
+                 GDataQuery *query,
+                 GType entry_type,
+                 SoupMessage *message,
+                 GCancellable *cancellable,
+                 GDataQueryProgressCallback progress_callback,
+                 gpointer progress_user_data,
+                 GError **error)
+{
+	GDataServiceClass *klass;
+	GDataFeed *feed = NULL;
+	SoupMessageHeaders *headers;
+	const gchar *content_type;
+
+	klass = GDATA_SERVICE_GET_CLASS (self);
 	headers = message->response_headers;
 	content_type = soup_message_headers_get_content_type (headers, NULL);
 
@@ -969,20 +1008,15 @@ __gdata_service_query (GDataService *self, GDataAuthorizationDomain *domain, con
 		/* Definitely JSON. */
 		g_debug("JSON content type detected.");
 		feed = _gdata_feed_new_from_json (klass->feed_type, message->response_body->data, message->response_body->length, entry_type,
-		                                  progress_callback, progress_user_data, is_async, error);
+		                                  progress_callback, progress_user_data, error);
 	} else {
 		/* Potentially XML. Don't bother checking the Content-Type, since the parser
 		 * will fail gracefully if the response body is not valid XML. */
 		g_debug("XML content type detected.");
 		feed = _gdata_feed_new_from_xml (klass->feed_type, message->response_body->data, message->response_body->length, entry_type,
-		                                 progress_callback, progress_user_data, is_async, error);
+		                                 progress_callback, progress_user_data, error);
 	}
 
-	g_object_unref (message);
-
-	if (feed == NULL)
-		return NULL;
-
 	/* Update the query with the feed's ETag */
 	if (query != NULL && feed != NULL && gdata_feed_get_etag (feed) != NULL)
 		gdata_query_set_etag (query, gdata_feed_get_etag (feed));
@@ -990,13 +1024,23 @@ __gdata_service_query (GDataService *self, GDataAuthorizationDomain *domain, con
 	/* Update the query with the next and previous URIs from the feed */
 	if (query != NULL && feed != NULL) {
 		GDataLink *_link;
+		const gchar *token;
 
-		_link = gdata_feed_look_up_link (feed, "next");
+		_gdata_query_clear_pagination (query);
+
+		/* Atom-style next and previous page links. */
+		_link = gdata_feed_look_up_link (feed, "http://www.iana.org/assignments/relation/next");
 		if (_link != NULL)
 			_gdata_query_set_next_uri (query, gdata_link_get_uri (_link));
-		_link = gdata_feed_look_up_link (feed, "previous");
+		_link = gdata_feed_look_up_link (feed, "http://www.iana.org/assignments/relation/previous");
 		if (_link != NULL)
 			_gdata_query_set_previous_uri (query, gdata_link_get_uri (_link));
+
+		/* JSON-style next page token. (There is no previous page
+		 * token.) */
+		token = gdata_feed_get_next_page_token (feed);
+		if (token != NULL)
+			_gdata_query_set_next_page_token (query, token);
 	}
 
 	return feed;
@@ -1037,7 +1081,7 @@ __gdata_service_query (GDataService *self, GDataAuthorizationDomain *domain, con
  * Return value: (transfer full): a #GDataFeed of query results, or %NULL; unref with g_object_unref()
  *
  * Since: 0.9.0
- **/
+ */
 GDataFeed *
 gdata_service_query (GDataService *self, GDataAuthorizationDomain *domain, const gchar *feed_uri, GDataQuery *query, GType entry_type,
                      GCancellable *cancellable, GDataQueryProgressCallback progress_callback, gpointer progress_user_data, GError **error)
@@ -1049,7 +1093,7 @@ gdata_service_query (GDataService *self, GDataAuthorizationDomain *domain, const
 	g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	return __gdata_service_query (self, domain, feed_uri, query, entry_type, cancellable, progress_callback, progress_user_data, error, FALSE);
+	return __gdata_service_query (self, domain, feed_uri, query, entry_type, cancellable, progress_callback, progress_user_data, error);
 }
 
 /**
@@ -1074,7 +1118,7 @@ gdata_service_query (GDataService *self, GDataAuthorizationDomain *domain, const
  * Return value: (transfer full): a #GDataEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.9.0
- **/
+ */
 GDataEntry *
 gdata_service_query_single_entry (GDataService *self, GDataAuthorizationDomain *domain, const gchar *entry_id, GDataQuery *query, GType entry_type,
                                   GCancellable *cancellable, GError **error)
@@ -1083,6 +1127,8 @@ gdata_service_query_single_entry (GDataService *self, GDataAuthorizationDomain *
 	GDataEntry *entry;
 	gchar *entry_uri;
 	SoupMessage *message;
+	SoupMessageHeaders *headers;
+	const gchar *content_type;
 
 	g_return_val_if_fail (GDATA_IS_SERVICE (self), NULL);
 	g_return_val_if_fail (domain == NULL || GDATA_IS_AUTHORIZATION_DOMAIN (domain), NULL);
@@ -1107,7 +1153,10 @@ gdata_service_query_single_entry (GDataService *self, GDataAuthorizationDomain *
 
 	g_assert (message->response_body->data != NULL);
 
-	if (g_strcmp0 (GDATA_PARSABLE_CLASS (klass)->get_content_type (), "application/json") == 0) {
+	headers = message->response_headers;
+	content_type = soup_message_headers_get_content_type (headers, NULL);
+
+	if (g_strcmp0 (content_type, "application/json") == 0) {
 		entry = GDATA_ENTRY (gdata_parsable_new_from_json (entry_type, message->response_body->data, message->response_body->length, error));
 	} else {
 		entry = GDATA_ENTRY (gdata_parsable_new_from_xml (entry_type, message->response_body->data, message->response_body->length, error));
@@ -1139,21 +1188,19 @@ query_single_entry_async_data_free (QuerySingleEntryAsyncData *data)
 }
 
 static void
-query_single_entry_thread (GSimpleAsyncResult *result, GDataService *service, GCancellable *cancellable)
+query_single_entry_thread (GTask *task, gpointer source_object, gpointer task_data, GCancellable *cancellable)
 {
-	GDataEntry *entry;
-	GError *error = NULL;
-	QuerySingleEntryAsyncData *data = g_simple_async_result_get_op_res_gpointer (result);
+	GDataService *service = GDATA_SERVICE (source_object);
+	g_autoptr(GDataEntry) entry = NULL;
+	g_autoptr(GError) error = NULL;
+	QuerySingleEntryAsyncData *data = task_data;
 
 	/* Execute the query and return */
 	entry = gdata_service_query_single_entry (service, data->domain, data->entry_id, data->query, data->entry_type, cancellable, &error);
-	if (entry == NULL && error != NULL) {
-		g_simple_async_result_set_from_error (result, error);
-		g_error_free (error);
-		return;
-	}
-
-	g_simple_async_result_set_op_res_gpointer (result, entry, (GDestroyNotify) g_object_unref);
+	if (entry == NULL && error != NULL)
+		g_task_return_error (task, g_steal_pointer (&error));
+	else
+		g_task_return_pointer (task, g_steal_pointer (&entry), g_object_unref);
 }
 
 /**
@@ -1177,12 +1224,12 @@ query_single_entry_thread (GSimpleAsyncResult *result, GDataService *service, GC
  * to get the results of the operation.
  *
  * Since: 0.9.0
- **/
+ */
 void
 gdata_service_query_single_entry_async (GDataService *self, GDataAuthorizationDomain *domain, const gchar *entry_id, GDataQuery *query,
                                         GType entry_type, GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-	GSimpleAsyncResult *result;
+	g_autoptr(GTask) task = NULL;
 	QuerySingleEntryAsyncData *data;
 
 	g_return_if_fail (GDATA_IS_SERVICE (self));
@@ -1199,10 +1246,10 @@ gdata_service_query_single_entry_async (GDataService *self, GDataAuthorizationDo
 	data->entry_id = g_strdup (entry_id);
 	data->entry_type = entry_type;
 
-	result = g_simple_async_result_new (G_OBJECT (self), callback, user_data, gdata_service_query_single_entry_async);
-	g_simple_async_result_set_op_res_gpointer (result, data, (GDestroyNotify) query_single_entry_async_data_free);
-	g_simple_async_result_run_in_thread (result, (GSimpleAsyncThreadFunc) query_single_entry_thread, G_PRIORITY_DEFAULT, cancellable);
-	g_object_unref (result);
+	task = g_task_new (self, cancellable, callback, user_data);
+	g_task_set_source_tag (task, gdata_service_query_single_entry_async);
+	g_task_set_task_data (task, g_steal_pointer (&data), (GDestroyNotify) query_single_entry_async_data_free);
+	g_task_run_in_thread (task, query_single_entry_thread);
 }
 
 /**
@@ -1216,26 +1263,17 @@ gdata_service_query_single_entry_async (GDataService *self, GDataAuthorizationDo
  * Return value: (transfer full): a #GDataEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.7.0
- **/
+ */
 GDataEntry *
 gdata_service_query_single_entry_finish (GDataService *self, GAsyncResult *async_result, GError **error)
 {
-	GSimpleAsyncResult *result = G_SIMPLE_ASYNC_RESULT (async_result);
-	GDataEntry *entry;
-
 	g_return_val_if_fail (GDATA_IS_SERVICE (self), NULL);
 	g_return_val_if_fail (G_IS_ASYNC_RESULT (async_result), NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+	g_return_val_if_fail (g_task_is_valid (async_result, self), NULL);
+	g_return_val_if_fail (g_async_result_is_tagged (async_result, gdata_service_query_single_entry_async), NULL);
 
-	g_warn_if_fail (g_simple_async_result_get_source_tag (result) == gdata_service_query_single_entry_async);
-
-	if (g_simple_async_result_propagate_error (result, error) == TRUE)
-		return NULL;
-
-	entry = g_simple_async_result_get_op_res_gpointer (result);
-	if (entry != NULL)
-		return g_object_ref (entry);
-	return NULL;
+	return g_task_propagate_pointer (G_TASK (async_result), error);
 }
 
 typedef struct {
@@ -1258,22 +1296,19 @@ insert_entry_async_data_free (InsertEntryAsyncData *self)
 }
 
 static void
-insert_entry_thread (GSimpleAsyncResult *result, GDataService *service, GCancellable *cancellable)
+insert_entry_thread (GTask *task, gpointer source_object, gpointer task_data, GCancellable *cancellable)
 {
-	GDataEntry *updated_entry;
-	GError *error = NULL;
-	InsertEntryAsyncData *data = g_simple_async_result_get_op_res_gpointer (result);
+	GDataService *service = GDATA_SERVICE (source_object);
+	g_autoptr(GDataEntry) updated_entry = NULL;
+	g_autoptr(GError) error = NULL;
+	InsertEntryAsyncData *data = task_data;
 
 	/* Insert the entry and return */
 	updated_entry = gdata_service_insert_entry (service, data->domain, data->upload_uri, data->entry, cancellable, &error);
-	if (updated_entry == NULL) {
-		g_simple_async_result_set_from_error (result, error);
-		g_error_free (error);
-		return;
-	}
-
-	/* Swap the old entry with the new one */
-	g_simple_async_result_set_op_res_gpointer (result, updated_entry, (GDestroyNotify) g_object_unref);
+	if (updated_entry == NULL)
+		g_task_return_error (task, g_steal_pointer (&error));
+	else
+		g_task_return_pointer (task, g_steal_pointer (&updated_entry), g_object_unref);
 }
 
 /**
@@ -1295,12 +1330,12 @@ insert_entry_thread (GSimpleAsyncResult *result, GDataService *service, GCancell
  * to get the results of the operation.
  *
  * Since: 0.9.0
- **/
+ */
 void
 gdata_service_insert_entry_async (GDataService *self, GDataAuthorizationDomain *domain, const gchar *upload_uri, GDataEntry *entry,
                                   GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-	GSimpleAsyncResult *result;
+	g_autoptr(GTask) task = NULL;
 	InsertEntryAsyncData *data;
 
 	g_return_if_fail (GDATA_IS_SERVICE (self));
@@ -1314,10 +1349,10 @@ gdata_service_insert_entry_async (GDataService *self, GDataAuthorizationDomain *
 	data->upload_uri = g_strdup (upload_uri);
 	data->entry = g_object_ref (entry);
 
-	result = g_simple_async_result_new (G_OBJECT (self), callback, user_data, gdata_service_insert_entry_async);
-	g_simple_async_result_set_op_res_gpointer (result, data, (GDestroyNotify) insert_entry_async_data_free);
-	g_simple_async_result_run_in_thread (result, (GSimpleAsyncThreadFunc) insert_entry_thread, G_PRIORITY_DEFAULT, cancellable);
-	g_object_unref (result);
+	task = g_task_new (self, cancellable, callback, user_data);
+	g_task_set_source_tag (task, gdata_service_insert_entry_async);
+	g_task_set_task_data (task, g_steal_pointer (&data), (GDestroyNotify) insert_entry_async_data_free);
+	g_task_run_in_thread (task, insert_entry_thread);
 }
 
 /**
@@ -1331,26 +1366,17 @@ gdata_service_insert_entry_async (GDataService *self, GDataAuthorizationDomain *
  * Return value: (transfer full): an updated #GDataEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.3.0
- **/
+ */
 GDataEntry *
 gdata_service_insert_entry_finish (GDataService *self, GAsyncResult *async_result, GError **error)
 {
-	GSimpleAsyncResult *result = G_SIMPLE_ASYNC_RESULT (async_result);
-	GDataEntry *entry;
-
 	g_return_val_if_fail (GDATA_IS_SERVICE (self), NULL);
 	g_return_val_if_fail (G_IS_ASYNC_RESULT (async_result), NULL);
-	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+	g_return_val_if_fail (g_task_is_valid (async_result, self), NULL);
+	g_return_val_if_fail (g_async_result_is_tagged (async_result, gdata_service_insert_entry_async), NULL);
 
-	g_warn_if_fail (g_simple_async_result_get_source_tag (result) == gdata_service_insert_entry_async);
-
-	if (g_simple_async_result_propagate_error (result, error) == TRUE)
-		return NULL;
-
-	entry = g_simple_async_result_get_op_res_gpointer (result);
-	g_assert (entry != NULL);
-
-	return g_object_ref (entry);
+	return g_task_propagate_pointer (G_TASK (async_result), error);
 }
 
 /**
@@ -1469,22 +1495,19 @@ update_entry_async_data_free (UpdateEntryAsyncData *data)
 }
 
 static void
-update_entry_thread (GSimpleAsyncResult *result, GDataService *service, GCancellable *cancellable)
+update_entry_thread (GTask *task, gpointer source_object, gpointer task_data, GCancellable *cancellable)
 {
-	GDataEntry *updated_entry;
-	GError *error = NULL;
-	UpdateEntryAsyncData *data = g_simple_async_result_get_op_res_gpointer (result);
+	GDataService *service = GDATA_SERVICE (source_object);
+	g_autoptr(GDataEntry) updated_entry = NULL;
+	g_autoptr(GError) error = NULL;
+	UpdateEntryAsyncData *data = task_data;
 
 	/* Update the entry and return */
 	updated_entry = gdata_service_update_entry (service, data->domain, data->entry, cancellable, &error);
-	if (updated_entry == NULL) {
-		g_simple_async_result_set_from_error (result, error);
-		g_error_free (error);
-		return;
-	}
-
-	/* Swap the old entry with the new one */
-	g_simple_async_result_set_op_res_gpointer (result, updated_entry, (GDestroyNotify) g_object_unref);
+	if (updated_entry == NULL)
+		g_task_return_error (task, g_steal_pointer (&error));
+	else
+		g_task_return_pointer (task, g_steal_pointer (&updated_entry), g_object_unref);
 }
 
 /**
@@ -1505,12 +1528,12 @@ update_entry_thread (GSimpleAsyncResult *result, GDataService *service, GCancell
  * to get the results of the operation.
  *
  * Since: 0.9.0
- **/
+ */
 void
 gdata_service_update_entry_async (GDataService *self, GDataAuthorizationDomain *domain, GDataEntry *entry,
                                   GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-	GSimpleAsyncResult *result;
+	g_autoptr(GTask) task = NULL;
 	UpdateEntryAsyncData *data;
 
 	g_return_if_fail (GDATA_IS_SERVICE (self));
@@ -1522,10 +1545,10 @@ gdata_service_update_entry_async (GDataService *self, GDataAuthorizationDomain *
 	data->domain = (domain != NULL) ? g_object_ref (domain) : NULL;
 	data->entry = g_object_ref (entry);
 
-	result = g_simple_async_result_new (G_OBJECT (self), callback, user_data, gdata_service_update_entry_async);
-	g_simple_async_result_set_op_res_gpointer (result, data, (GDestroyNotify) update_entry_async_data_free);
-	g_simple_async_result_run_in_thread (result, (GSimpleAsyncThreadFunc) update_entry_thread, G_PRIORITY_DEFAULT, cancellable);
-	g_object_unref (result);
+	task = g_task_new (task, cancellable, callback, user_data);
+	g_task_set_source_tag (task, gdata_service_update_entry_async);
+	g_task_set_task_data (task, g_steal_pointer (&data), (GDestroyNotify) update_entry_async_data_free);
+	g_task_run_in_thread (task, update_entry_thread);
 }
 
 /**
@@ -1539,26 +1562,17 @@ gdata_service_update_entry_async (GDataService *self, GDataAuthorizationDomain *
  * Return value: (transfer full): an updated #GDataEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.3.0
- **/
+ */
 GDataEntry *
 gdata_service_update_entry_finish (GDataService *self, GAsyncResult *async_result, GError **error)
 {
-	GSimpleAsyncResult *result = G_SIMPLE_ASYNC_RESULT (async_result);
-	GDataEntry *entry;
-
 	g_return_val_if_fail (GDATA_IS_SERVICE (self), NULL);
 	g_return_val_if_fail (G_IS_ASYNC_RESULT (async_result), NULL);
-	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+	g_return_val_if_fail (g_task_is_valid (async_result, self), NULL);
+	g_return_val_if_fail (g_async_result_is_tagged (async_result, gdata_service_update_entry_async), NULL);
 
-	g_warn_if_fail (g_simple_async_result_get_source_tag (result) == gdata_service_update_entry_async);
-
-	if (g_simple_async_result_propagate_error (result, error) == TRUE)
-		return NULL;
-
-	entry = g_simple_async_result_get_op_res_gpointer (result);
-	g_assert (entry != NULL);
-
-	return g_object_ref (entry);
+	return g_task_propagate_pointer (G_TASK (async_result), error);
 }
 
 /**
@@ -1587,7 +1601,7 @@ gdata_service_update_entry_finish (GDataService *self, GAsyncResult *async_resul
  * Return value: (transfer full): an updated #GDataEntry, or %NULL; unref with g_object_unref()
  *
  * Since: 0.9.0
- **/
+ */
 GDataEntry *
 gdata_service_update_entry (GDataService *self, GDataAuthorizationDomain *domain, GDataEntry *entry, GCancellable *cancellable, GError **error)
 {
@@ -1671,22 +1685,17 @@ delete_entry_async_data_free (DeleteEntryAsyncData *data)
 }
 
 static void
-delete_entry_thread (GSimpleAsyncResult *result, GDataService *service, GCancellable *cancellable)
+delete_entry_thread (GTask *task, gpointer source_object, gpointer task_data, GCancellable *cancellable)
 {
-	gboolean success;
-	GError *error = NULL;
-	DeleteEntryAsyncData *data = g_simple_async_result_get_op_res_gpointer (result);
+	GDataService *service = GDATA_SERVICE (source_object);
+	g_autoptr(GError) error = NULL;
+	DeleteEntryAsyncData *data = task_data;
 
 	/* Delete the entry and return */
-	success = gdata_service_delete_entry (service, data->domain, data->entry, cancellable, &error);
-	if (success == FALSE) {
-		g_simple_async_result_set_from_error (result, error);
-		g_error_free (error);
-		return;
-	}
-
-	/* Replace the entry with the success value */
-	g_simple_async_result_set_op_res_gboolean (result, success);
+	if (!gdata_service_delete_entry (service, data->domain, data->entry, cancellable, &error))
+		g_task_return_error (task, g_steal_pointer (&error));
+	else
+		g_task_return_boolean (task, TRUE);
 }
 
 /**
@@ -1707,12 +1716,12 @@ delete_entry_thread (GSimpleAsyncResult *result, GDataService *service, GCancell
  * to get the results of the operation.
  *
  * Since: 0.9.0
- **/
+ */
 void
 gdata_service_delete_entry_async (GDataService *self, GDataAuthorizationDomain *domain, GDataEntry *entry,
                                   GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-	GSimpleAsyncResult *result;
+	g_autoptr(GTask) task = NULL;
 	DeleteEntryAsyncData *data;
 
 	g_return_if_fail (GDATA_IS_SERVICE (self));
@@ -1724,10 +1733,10 @@ gdata_service_delete_entry_async (GDataService *self, GDataAuthorizationDomain *
 	data->domain = (domain != NULL) ? g_object_ref (domain) : NULL;
 	data->entry = g_object_ref (entry);
 
-	result = g_simple_async_result_new (G_OBJECT (self), callback, user_data, gdata_service_delete_entry_async);
-	g_simple_async_result_set_op_res_gpointer (result, data, (GDestroyNotify) delete_entry_async_data_free);
-	g_simple_async_result_run_in_thread (result, (GSimpleAsyncThreadFunc) delete_entry_thread, G_PRIORITY_DEFAULT, cancellable);
-	g_object_unref (result);
+	task = g_task_new (self, cancellable, callback, user_data);
+	g_task_set_source_tag (task, gdata_service_delete_entry_async);
+	g_task_set_task_data (task, g_steal_pointer (&data), (GDestroyNotify) delete_entry_async_data_free);
+	g_task_run_in_thread (task, delete_entry_thread);
 }
 
 /**
@@ -1741,22 +1750,17 @@ gdata_service_delete_entry_async (GDataService *self, GDataAuthorizationDomain *
  * Return value: %TRUE on success, %FALSE otherwise
  *
  * Since: 0.3.0
- **/
+ */
 gboolean
 gdata_service_delete_entry_finish (GDataService *self, GAsyncResult *async_result, GError **error)
 {
-	GSimpleAsyncResult *result = G_SIMPLE_ASYNC_RESULT (async_result);
-
 	g_return_val_if_fail (GDATA_IS_SERVICE (self), FALSE);
 	g_return_val_if_fail (G_IS_ASYNC_RESULT (async_result), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+	g_return_val_if_fail (g_task_is_valid (async_result, self), FALSE);
+	g_return_val_if_fail (g_async_result_is_tagged (async_result, gdata_service_delete_entry_async), FALSE);
 
-	g_warn_if_fail (g_simple_async_result_get_source_tag (result) == gdata_service_delete_entry_async);
-
-	if (g_simple_async_result_propagate_error (result, error) == TRUE)
-		return FALSE;
-
-	return g_simple_async_result_get_op_res_gboolean (result);
+	return g_task_propagate_boolean (G_TASK (async_result), error);
 }
 
 /**
@@ -1783,7 +1787,7 @@ gdata_service_delete_entry_finish (GDataService *self, GAsyncResult *async_resul
  * Return value: %TRUE on success, %FALSE otherwise
  *
  * Since: 0.9.0
- **/
+ */
 gboolean
 gdata_service_delete_entry (GDataService *self, GDataAuthorizationDomain *domain, GDataEntry *entry, GCancellable *cancellable, GError **error)
 {
@@ -1864,8 +1868,8 @@ _get_proxy_uri (GDataService *self)
  * Return value: (transfer none): the proxy URI, or %NULL
  *
  * Since: 0.2.0
- * Deprecated: Use gdata_service_get_proxy_resolver() instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
- **/
+ * Deprecated: 0.15.0: Use gdata_service_get_proxy_resolver() instead, which gives more flexibility over the proxy used.
+ */
 SoupURI *
 gdata_service_get_proxy_uri (GDataService *self)
 {
@@ -1894,8 +1898,8 @@ _set_proxy_uri (GDataService *self, SoupURI *proxy_uri)
  * Note that if a #GDataAuthorizer is being used with this #GDataService, the authorizer might also need its proxy URI setting.
  *
  * Since: 0.2.0
- * Deprecated: Use gdata_service_set_proxy_resolver() instead, which gives more flexibility over the proxy used. (Since: 0.15.0.)
- **/
+ * Deprecated: 0.15.0: Use gdata_service_set_proxy_resolver() instead, which gives more flexibility over the proxy used.
+ */
 void
 gdata_service_set_proxy_uri (GDataService *self, SoupURI *proxy_uri)
 {
@@ -1962,7 +1966,7 @@ notify_timeout_cb (GObject *gobject, GParamSpec *pspec, GObject *self)
  * Return value: the timeout, or <code class="literal">0</code>
  *
  * Since: 0.7.0
- **/
+ */
 guint
 gdata_service_get_timeout (GDataService *self)
 {
@@ -1987,7 +1991,7 @@ gdata_service_get_timeout (GDataService *self)
  * Note that if a #GDataAuthorizer is being used with this #GDataService, the authorizer might also need its timeout setting.
  *
  * Since: 0.7.0
- **/
+ */
 void
 gdata_service_set_timeout (GDataService *self, guint timeout)
 {
@@ -2279,7 +2283,7 @@ soup_log_printer (SoupLogger *logger, SoupLoggerLogLevel level, char direction,
  * Return value: the log level
  *
  * Since: 0.7.0
- **/
+ */
 GDataLogLevel
 _gdata_service_get_log_level (void)
 {
@@ -2384,7 +2388,7 @@ _gdata_service_build_session (void)
  * Return value: the current locale
  *
  * Since: 0.7.0
- **/
+ */
 const gchar *
 gdata_service_get_locale (GDataService *self)
 {
@@ -2403,7 +2407,7 @@ gdata_service_get_locale (GDataService *self)
  * unexpectedly. The only supported use of this function is after creation of a service, but before any network requests are made.
  *
  * Since: 0.7.0
- **/
+ */
 void
 gdata_service_set_locale (GDataService *self, const gchar *locale)
 {
