@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * GData Client
- * Copyright (C) Philip Withnall 2009–2010 <philip@tecnocode.co.uk>
+ * Copyright (C) Philip Withnall 2009, 2010, 2017 <philip@tecnocode.co.uk>
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -50,7 +50,6 @@
  *	g_get_current_time (&current_time);
  *	query = gdata_calendar_query_new_with_limits ("party", current_time.tv_sec, current_time.tv_sec + 7 * 24 * 60 * 60);
  *	gdata_calendar_query_set_order_by (query, "lastmodified");
- *	gdata_calendar_query_set_sort_order (query, "descending");
  *
  *	/<!-- -->* Execute the query *<!-- -->/
  *	feed = gdata_calendar_service_query_events (service, calendar, query, NULL, NULL, NULL, &error);
@@ -75,7 +74,7 @@
  *	g_object_unref (feed);
  * 	</programlisting>
  * </example>
- **/
+ */
 
 #include <config.h>
 #include <glib.h>
@@ -85,6 +84,7 @@
 #include "gdata-calendar-query.h"
 #include "gdata-query.h"
 #include "gdata-parser.h"
+#include "gdata-private.h"
 
 static void gdata_calendar_query_finalize (GObject *object);
 static void gdata_calendar_query_get_property (GObject *object, guint property_id, GValue *value, GParamSpec *pspec);
@@ -98,8 +98,8 @@ struct _GDataCalendarQueryPrivate {
 	gint64 recurrence_expansion_end;
 	gboolean single_events;
 	gchar *sort_order; /* TODO: #defined values */
-	gint64 start_min;
-	gint64 start_max;
+	gint64 start_min;  /* UNIX timestamp, seconds */
+	gint64 start_max;  /* UNIX timestamp, seconds */
 	gchar *timezone;
 	guint max_attendees;
 	gboolean show_deleted;
@@ -141,7 +141,7 @@ gdata_calendar_query_class_init (GDataCalendarQueryClass *klass)
 	 * A shortcut to request all events scheduled for the future. Overrides the
 	 * #GDataCalendarQuery:recurrence-expansion-start, #GDataCalendarQuery:recurrence-expansion-end,
 	 * #GDataCalendarQuery:start-min and #GDataCalendarQuery:start-max properties.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_FUTURE_EVENTS,
 	                                 g_param_spec_boolean ("future-events",
 	                                                       "Future events?", "A shortcut to request all events scheduled for the future.",
@@ -153,7 +153,7 @@ gdata_calendar_query_class_init (GDataCalendarQueryClass *klass)
 	 *
 	 * Specifies order of entries in a feed. Supported values are <literal>lastmodified</literal> and
 	 * <literal>starttime</literal>.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_ORDER_BY,
 	                                 g_param_spec_string ("order-by",
 	                                                      "Order by", "Specifies order of entries in a feed.",
@@ -164,29 +164,33 @@ gdata_calendar_query_class_init (GDataCalendarQueryClass *klass)
 	 * GDataCalendarQuery:recurrence-expansion-start:
 	 *
 	 * Specifies the beginning of the time period to expand recurring events for, inclusive.
-	 **/
+	 *
+	 * Deprecated: 0.17.7: Use #GDataCalendarQuery:single-events instead, as this is no longer supported on the server.
+	 */
 	g_object_class_install_property (gobject_class, PROP_RECURRENCE_EXPANSION_START,
 	                                 g_param_spec_int64 ("recurrence-expansion-start",
 	                                                     "Recurrence expansion start", "Specifies start of period to expand recurrences for.",
 	                                                     -1, G_MAXINT64, -1,
-	                                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+	                                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_DEPRECATED));
 
 	/**
 	 * GDataCalendarQuery:recurrence-expansion-end:
 	 *
 	 * Specifies the end of the time period to expand recurring events for, exclusive.
-	 **/
+	 *
+	 * Deprecated: 0.17.7: Use #GDataCalendarQuery:single-events instead, as this is no longer supported on the server.
+	 */
 	g_object_class_install_property (gobject_class, PROP_RECURRENCE_EXPANSION_END,
 	                                 g_param_spec_int64 ("recurrence-expansion-end",
 	                                                     "Recurrence expansion end", "Specifies end of period to expand recurrences for.",
 	                                                     -1, G_MAXINT64, -1,
-	                                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+	                                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_DEPRECATED));
 
 	/**
 	 * GDataCalendarQuery:single-events:
 	 *
 	 * Indicates whether recurring events should be expanded or represented as a single event.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_SINGLE_EVENTS,
 	                                 g_param_spec_boolean ("single-events",
 	                                                       "Single events?", "Indicates whether recurring events should be expanded.",
@@ -198,12 +202,16 @@ gdata_calendar_query_class_init (GDataCalendarQueryClass *klass)
 	 *
 	 * Specifies direction of sorting. Supported values are <literal>ascending</literal> and
 	 * <literal>descending</literal>.
-	 **/
+	 *
+	 * By default, results are returned in ascending order.
+	 *
+	 * Deprecated: 0.17.7: Manually sort the results after retrieving them, as this is no longer supported on the server.
+	 */
 	g_object_class_install_property (gobject_class, PROP_SORT_ORDER,
 	                                 g_param_spec_string ("sort-order",
 	                                                      "Sort order", "Specifies direction of sorting.",
 	                                                      NULL,
-	                                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+	                                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_DEPRECATED));
 
 	/**
 	 * GDataCalendarQuery:start-min:
@@ -211,10 +219,10 @@ gdata_calendar_query_class_init (GDataCalendarQueryClass *klass)
 	 * Together with #GDataCalendarQuery:start-max, creates a timespan such that only events within the timespan are returned.
 	 *
 	 * #GDataCalendarQuery:start-min is inclusive, while #GDataCalendarQuery:start-max is exclusive. Events that overlap the range are
-	 * included.
+	 * included. Both are specified in seconds since the UNIX epoch.
 	 *
 	 * If not specified, the default #GDataCalendarQuery:start-min is <literal>1970-01-01</literal>.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_START_MIN,
 	                                 g_param_spec_int64 ("start-min",
 	                                                     "Start min", "A timespan such that only events within the timespan are returned.",
@@ -227,10 +235,10 @@ gdata_calendar_query_class_init (GDataCalendarQueryClass *klass)
 	 * Together with #GDataCalendarQuery:start-min, creates a timespan such that only events within the timespan are returned
 	 *
 	 * #GDataCalendarQuery:start-min is inclusive, while #GDataCalendarQuery:start-max is exclusive. Events that overlap the range are
-	 * included.
+	 * included. Both are specified in seconds since the UNIX epoch.
 	 *
 	 * If not specified, the default #GDataCalendarQuery:start-max is <literal>2031-01-01</literal>.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_START_MAX,
 	                                 g_param_spec_int64 ("start-max",
 	                                                     "Start max", "A timespan such that only events within the timespan are returned.",
@@ -243,7 +251,7 @@ gdata_calendar_query_class_init (GDataCalendarQueryClass *klass)
 	 * The current timezone. If this is not specified, all times are returned in UTC.
 	 *
 	 * Since: 0.2.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_TIMEZONE,
 	                                 g_param_spec_string ("timezone",
 	                                                      "Timezone", "The current timezone.",
@@ -287,6 +295,9 @@ gdata_calendar_query_init (GDataCalendarQuery *self)
 	self->priv->recurrence_expansion_end = -1;
 	self->priv->start_min = -1;
 	self->priv->start_max = -1;
+
+	_gdata_query_set_pagination_type (GDATA_QUERY (self),
+	                                  GDATA_QUERY_PAGINATION_TOKENS);
 }
 
 static void
@@ -361,16 +372,22 @@ gdata_calendar_query_set_property (GObject *object, guint property_id, const GVa
 			gdata_calendar_query_set_order_by (self, g_value_get_string (value));
 			break;
 		case PROP_RECURRENCE_EXPANSION_START:
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 			gdata_calendar_query_set_recurrence_expansion_start (self, g_value_get_int64 (value));
+G_GNUC_END_IGNORE_DEPRECATIONS
 			break;
 		case PROP_RECURRENCE_EXPANSION_END:
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 			gdata_calendar_query_set_recurrence_expansion_end (self, g_value_get_int64 (value));
+G_GNUC_END_IGNORE_DEPRECATIONS
 			break;
 		case PROP_SINGLE_EVENTS:
 			gdata_calendar_query_set_single_events (self, g_value_get_boolean (value));
 			break;
 		case PROP_SORT_ORDER:
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 			gdata_calendar_query_set_sort_order (self, g_value_get_string (value));
+G_GNUC_END_IGNORE_DEPRECATIONS
 			break;
 		case PROP_START_MIN:
 			gdata_calendar_query_set_start_min (self, g_value_get_int64 (value));
@@ -394,6 +411,21 @@ gdata_calendar_query_set_property (GObject *object, guint property_id, const GVa
 	}
 }
 
+/* Convert the v2 order-by values to the v3 orderBy values:
+ *  - https://developers.google.com/google-apps/calendar/v3/reference/events/list#orderBy
+ *  - There is no reference for v2 any more.
+ */
+static const gchar *
+order_by_to_v3 (const gchar *order_by)
+{
+	if (g_strcmp0 (order_by, "lastmodified") == 0)
+		return "updated";
+	else if (g_strcmp0 (order_by, "starttime") == 0)
+		return "startTime";
+	else
+		return order_by;
+}
+
 static void
 get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboolean *params_started)
 {
@@ -404,65 +436,49 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 	/* Chain up to the parent class */
 	GDATA_QUERY_CLASS (gdata_calendar_query_parent_class)->get_query_uri (self, feed_uri, query_uri, params_started);
 
-	APPEND_SEP
-	if (priv->future_events == TRUE)
-		g_string_append (query_uri, "futureevents=true");
-	else
-		g_string_append (query_uri, "futureevents=false");
+	if (gdata_query_get_max_results (GDATA_QUERY (self)) != 0) {
+		APPEND_SEP
+		g_string_append_printf (query_uri, "maxResults=%u",
+		                        gdata_query_get_max_results (GDATA_QUERY (self)));
+	}
 
 	if (priv->order_by != NULL) {
 		APPEND_SEP
-		g_string_append (query_uri, "orderby=");
-		g_string_append_uri_escaped (query_uri, priv->order_by, NULL, FALSE);
-	}
-
-	if (priv->recurrence_expansion_start != -1) {
-		gchar *recurrence_expansion_start;
-
-		APPEND_SEP
-		g_string_append (query_uri, "recurrence-expansion-start=");
-		recurrence_expansion_start = gdata_parser_int64_to_iso8601 (priv->recurrence_expansion_start);
-		g_string_append (query_uri, recurrence_expansion_start);
-		g_free (recurrence_expansion_start);
-	}
-
-	if (priv->recurrence_expansion_end != -1) {
-		gchar *recurrence_expansion_end;
-
-		APPEND_SEP
-		g_string_append (query_uri, "recurrence-expansion-end=");
-		recurrence_expansion_end = gdata_parser_int64_to_iso8601 (priv->recurrence_expansion_end);
-		g_string_append (query_uri, recurrence_expansion_end);
-		g_free (recurrence_expansion_end);
+		g_string_append (query_uri, "orderBy=");
+		g_string_append_uri_escaped (query_uri,
+		                             order_by_to_v3 (priv->order_by), NULL, FALSE);
 	}
 
+	/* Convert the deprecated recurrence-expansion-* properties into single-events. */
 	APPEND_SEP
-	if (priv->single_events == TRUE)
-		g_string_append (query_uri, "singleevents=true");
+	if (priv->single_events == TRUE ||
+	    priv->recurrence_expansion_start >= 0 ||
+	    priv->recurrence_expansion_end >= 0)
+		g_string_append (query_uri, "singleEvents=true");
 	else
-		g_string_append (query_uri, "singleevents=false");
-
-	if (priv->sort_order != NULL) {
-		APPEND_SEP
-		g_string_append (query_uri, "sortorder=");
-		g_string_append_uri_escaped (query_uri, priv->sort_order, NULL, FALSE);
-	}
+		g_string_append (query_uri, "singleEvents=false");
 
 	if (priv->start_min != -1) {
 		gchar *start_min;
+		gint64 start_min_time;
+
+		if (priv->future_events)
+			start_min_time = g_get_real_time () / G_USEC_PER_SEC;
+		else
+			start_min_time = priv->start_min;
 
 		APPEND_SEP
-		g_string_append (query_uri, "start-min=");
-		start_min = gdata_parser_int64_to_iso8601 (priv->start_min);
+		g_string_append (query_uri, "timeMin=");
+		start_min = gdata_parser_int64_to_iso8601 (start_min_time);
 		g_string_append (query_uri, start_min);
 		g_free (start_min);
 	}
 
-	if (priv->start_max != -1) {
+	if (priv->start_max != -1 && !priv->future_events) {
 		gchar *start_max;
 
 		APPEND_SEP
-		g_string_append (query_uri, "start-max=");
+		g_string_append (query_uri, "timeMax=");
 		start_max = gdata_parser_int64_to_iso8601 (priv->start_max);
 		g_string_append (query_uri, start_max);
 		g_free (start_max);
@@ -470,20 +486,20 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 
 	if (priv->timezone != NULL) {
 		APPEND_SEP
-		g_string_append (query_uri, "ctz=");
+		g_string_append (query_uri, "timeZone=");
 		g_string_append_uri_escaped (query_uri, priv->timezone, NULL, FALSE);
 	}
 
 	if (priv->max_attendees > 0) {
 		APPEND_SEP
-		g_string_append_printf (query_uri, "max-attendees=%u", priv->max_attendees);
+		g_string_append_printf (query_uri, "maxAttendees=%u", priv->max_attendees);
 	}
 
 	APPEND_SEP
 	if (priv->show_deleted == TRUE) {
-		g_string_append (query_uri, "showdeleted=true");
+		g_string_append (query_uri, "showDeleted=true");
 	} else {
-		g_string_append (query_uri, "showdeleted=false");
+		g_string_append (query_uri, "showDeleted=false");
 	}
 }
 
@@ -494,7 +510,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
  * Creates a new #GDataCalendarQuery with its #GDataQuery:q property set to @q.
  *
  * Return value: a new #GDataCalendarQuery
- **/
+ */
 GDataCalendarQuery *
 gdata_calendar_query_new (const gchar *q)
 {
@@ -508,10 +524,10 @@ gdata_calendar_query_new (const gchar *q)
  * @start_max: an ending time for the event period, or -1
  *
  * Creates a new #GDataCalendarQuery with its #GDataQuery:q property set to @q, and the time limits @start_min and @start_max
- * applied.
+ * applied (both in seconds since the UNIX epoch).
  *
  * Return value: a new #GDataCalendarQuery
- **/
+ */
 GDataCalendarQuery *
 gdata_calendar_query_new_with_limits (const gchar *q, gint64 start_min, gint64 start_max)
 {
@@ -529,7 +545,7 @@ gdata_calendar_query_new_with_limits (const gchar *q, gint64 start_min, gint64 s
  * Gets the #GDataCalendarQuery:future-events property.
  *
  * Return value: the future events property
- **/
+ */
 gboolean
 gdata_calendar_query_get_future_events (GDataCalendarQuery *self)
 {
@@ -543,7 +559,7 @@ gdata_calendar_query_get_future_events (GDataCalendarQuery *self)
  * @future_events: %TRUE to unconditionally show future events, %FALSE otherwise
  *
  * Sets the #GDataCalendarQuery:future-events property of the #GDataCalendarQuery to @future_events.
- **/
+ */
 void
 gdata_calendar_query_set_future_events (GDataCalendarQuery *self, gboolean future_events)
 {
@@ -562,7 +578,7 @@ gdata_calendar_query_set_future_events (GDataCalendarQuery *self, gboolean futur
  * Gets the #GDataCalendarQuery:order-by property.
  *
  * Return value: the order by property, or %NULL if it is unset
- **/
+ */
 const gchar *
 gdata_calendar_query_get_order_by (GDataCalendarQuery *self)
 {
@@ -578,7 +594,7 @@ gdata_calendar_query_get_order_by (GDataCalendarQuery *self)
  * Sets the #GDataCalendarQuery:order-by property of the #GDataCalendarQuery to the new order by string, @order_by.
  *
  * Set @order_by to %NULL to unset the property in the query URI.
- **/
+ */
 void
 gdata_calendar_query_set_order_by (GDataCalendarQuery *self, const gchar *order_by)
 {
@@ -599,7 +615,8 @@ gdata_calendar_query_set_order_by (GDataCalendarQuery *self, const gchar *order_
  * Gets the #GDataCalendarQuery:recurrence-expansion-start property. If the property is unset, <code class="literal">-1</code> will be returned.
  *
  * Return value: the UNIX timestamp for the recurrence-expansion-start property, or <code class="literal">-1</code>
- **/
+ * Deprecated: 0.17.7: Use #GDataCalendarQuery:single-events instead, as this is no longer supported on the server.
+ */
 gint64
 gdata_calendar_query_get_recurrence_expansion_start (GDataCalendarQuery *self)
 {
@@ -616,7 +633,9 @@ gdata_calendar_query_get_recurrence_expansion_start (GDataCalendarQuery *self)
  * to the new time/date, @start.
  *
  * Set @start to <code class="literal">-1</code> to unset the property in the query URI.
- **/
+ *
+ * Deprecated: 0.17.7: Use #GDataCalendarQuery:single-events instead, as this is no longer supported on the server.
+ */
 void
 gdata_calendar_query_set_recurrence_expansion_start (GDataCalendarQuery *self, gint64 start)
 {
@@ -637,7 +656,9 @@ gdata_calendar_query_set_recurrence_expansion_start (GDataCalendarQuery *self, g
  * Gets the #GDataCalendarQuery:recurrence-expansion-end property. If the property is unset, <code class="literal">-1</code> will be returned.
  *
  * Return value: the UNIX timestamp for the recurrence-expansion-end property, or <code class="literal">-1</code>
- **/
+ *
+ * Deprecated: 0.17.7: Use #GDataCalendarQuery:single-events instead, as this is no longer supported on the server.
+ */
 gint64
 gdata_calendar_query_get_recurrence_expansion_end (GDataCalendarQuery *self)
 {
@@ -654,7 +675,9 @@ gdata_calendar_query_get_recurrence_expansion_end (GDataCalendarQuery *self)
  * to the new time/date, @end.
  *
  * Set @end to <code class="literal">-1</code> to unset the property in the query URI.
- **/
+ *
+ * Deprecated: 0.17.7: Use #GDataCalendarQuery:single-events instead, as this is no longer supported on the server.
+ */
 void
 gdata_calendar_query_set_recurrence_expansion_end (GDataCalendarQuery *self, gint64 end)
 {
@@ -675,7 +698,7 @@ gdata_calendar_query_set_recurrence_expansion_end (GDataCalendarQuery *self, gin
  * Gets the #GDataCalendarQuery:single-events property.
  *
  * Return value: the single events property
- **/
+ */
 gboolean
 gdata_calendar_query_get_single_events (GDataCalendarQuery *self)
 {
@@ -689,7 +712,7 @@ gdata_calendar_query_get_single_events (GDataCalendarQuery *self)
  * @single_events: %TRUE to show recurring events as single events, %FALSE otherwise
  *
  * Sets the #GDataCalendarQuery:single-events property of the #GDataCalendarQuery to @single_events.
- **/
+ */
 void
 gdata_calendar_query_set_single_events (GDataCalendarQuery *self, gboolean single_events)
 {
@@ -708,7 +731,8 @@ gdata_calendar_query_set_single_events (GDataCalendarQuery *self, gboolean singl
  * Gets the #GDataCalendarQuery:sort-order property.
  *
  * Return value: the sort order property, or %NULL if it is unset
- **/
+ * Deprecated: 0.17.7: Manually sort the results after retrieving them, as this is no longer supported on the server.
+ */
 const gchar *
 gdata_calendar_query_get_sort_order (GDataCalendarQuery *self)
 {
@@ -724,7 +748,9 @@ gdata_calendar_query_get_sort_order (GDataCalendarQuery *self)
  * Sets the #GDataCalendarQuery:sort-order property of the #GDataCalendarQuery to the new sort order string, @sort_order.
  *
  * Set @sort_order to %NULL to unset the property in the query URI.
- **/
+ *
+ * Deprecated: 0.17.7: Manually sort the results after retrieving them, as this is no longer supported on the server.
+ */
 void
 gdata_calendar_query_set_sort_order (GDataCalendarQuery *self, const gchar *sort_order)
 {
@@ -744,8 +770,8 @@ gdata_calendar_query_set_sort_order (GDataCalendarQuery *self, const gchar *sort
  *
  * Gets the #GDataCalendarQuery:start-min property. If the property is unset, <code class="literal">-1</code> will be returned.
  *
- * Return value: the UNIX timestamp for the start-min property, or <code class="literal">-1</code>
- **/
+ * Return value: the UNIX timestamp (in seconds) for the start-min property, or <code class="literal">-1</code>
+ */
 gint64
 gdata_calendar_query_get_start_min (GDataCalendarQuery *self)
 {
@@ -756,13 +782,13 @@ gdata_calendar_query_get_start_min (GDataCalendarQuery *self)
 /**
  * gdata_calendar_query_set_start_min:
  * @self: a #GDataCalendarQuery
- * @start_min: a new minimum start time, or <code class="literal">-1</code>
+ * @start_min: a new minimum start time (in seconds since the UNIX epoch), or <code class="literal">-1</code>
  *
  * Sets the #GDataCalendarQuery:start-min property of the #GDataCalendarQuery
  * to the new time/date, @start_min.
  *
  * Set @start_min to <code class="literal">-1</code> to unset the property in the query URI.
- **/
+ */
 void
 gdata_calendar_query_set_start_min (GDataCalendarQuery *self, gint64 start_min)
 {
@@ -782,8 +808,8 @@ gdata_calendar_query_set_start_min (GDataCalendarQuery *self, gint64 start_min)
  *
  * Gets the #GDataCalendarQuery:start-max property. If the property is unset, <code class="literal">-1</code> will be returned.
  *
- * Return value: the UNIX timestamp for the start-max property, or <code class="literal">-1</code>
- **/
+ * Return value: the UNIX timestamp (in seconds) for the start-max property, or <code class="literal">-1</code>
+ */
 gint64
 gdata_calendar_query_get_start_max (GDataCalendarQuery *self)
 {
@@ -794,13 +820,13 @@ gdata_calendar_query_get_start_max (GDataCalendarQuery *self)
 /**
  * gdata_calendar_query_set_start_max:
  * @self: a #GDataCalendarQuery
- * @start_max: a new maximum start time, or <code class="literal">-1</code>
+ * @start_max: a new maximum start time (in seconds since the UNIX epoch), or <code class="literal">-1</code>
  *
  * Sets the #GDataCalendarQuery:start-max property of the #GDataCalendarQuery
  * to the new time/date, @start_max.
  *
  * Set @start_max to <code class="literal">-1</code> to unset the property in the query URI.
- **/
+ */
 void
 gdata_calendar_query_set_start_max (GDataCalendarQuery *self, gint64 start_max)
 {
@@ -823,7 +849,7 @@ gdata_calendar_query_set_start_max (GDataCalendarQuery *self, gint64 start_max)
  * Return value: the timezone property, or %NULL if it is unset
  *
  * Since: 0.2.0
- **/
+ */
 const gchar *
 gdata_calendar_query_get_timezone (GDataCalendarQuery *self)
 {
@@ -841,7 +867,7 @@ gdata_calendar_query_get_timezone (GDataCalendarQuery *self)
  * Set @timezone to %NULL to unset the property in the query URI.
  *
  * Since: 0.2.0
- **/
+ */
 void
 gdata_calendar_query_set_timezone (GDataCalendarQuery *self, const gchar *_timezone)
 {
