@@ -24,7 +24,7 @@
  * @stability: Stable
  * @include: gdata/services/documents/gdata-documents-entry.h
  *
- * #GDataDocumentsEntry is a subclass of #GDataEntry to represent a Google Documents entry, which is then further subclassed
+ * #GDataDocumentsEntry is a subclass of #GDataEntry to represent a Google Drive entry, which is then further subclassed
  * to give specific document types.
  *
  * #GDataDocumentsEntry implements #GDataAccessHandler, meaning the access rules to it can be modified using that interface. As well as the
@@ -36,8 +36,8 @@
  * and document ID should almost always be considered as internal, and thus entry IDs (#GDataEntry:id) should normally be used to uniquely identify
  * documents. For more information, see #GDataDocumentsEntry:resource-id.
  *
- * For more details of Google Documents' GData API, see the
- * <ulink type="http" url="https://developers.google.com/google-apps/documents-list/">online documentation</ulink>.
+ * For more details of Google Drive's GData API, see the
+ * <ulink type="http" url="https://developers.google.com/drive/v2/web/about-sdk">online documentation</ulink>.
  *
  * <example>
  * 	<title>Moving an Entry Between Folders</title>
@@ -92,12 +92,11 @@
  * </example>
  *
  * Since: 0.4.0
- **/
+ */
 
 #include <config.h>
 #include <glib.h>
 #include <glib/gi18n-lib.h>
-#include <string.h>
 
 #include "gdata-documents-entry.h"
 #include "gdata-parser.h"
@@ -127,12 +126,12 @@ static gchar *get_entry_uri (const gchar *id);
 
 struct _GDataDocumentsEntryPrivate {
 	gint64 last_viewed;
-	gchar *mime_type;
 	gchar *resource_id;
 	gboolean writers_can_invite;
 	gboolean is_deleted;
 	GDataAuthor *last_modified_by;
 	goffset quota_used; /* bytes */
+	goffset file_size; /* bytes */
 };
 
 enum {
@@ -144,6 +143,7 @@ enum {
 	PROP_WRITERS_CAN_INVITE,
 	PROP_RESOURCE_ID,
 	PROP_QUOTA_USED,
+	PROP_FILE_SIZE,
 };
 
 G_DEFINE_ABSTRACT_TYPE_WITH_CODE (GDataDocumentsEntry, gdata_documents_entry, GDATA_TYPE_ENTRY,
@@ -178,7 +178,7 @@ gdata_documents_entry_class_init (GDataDocumentsEntryClass *klass)
 	 *
 	 * Since: 0.4.0
 	 * Deprecated: 0.17.0: This is identical to #GDataEntry:updated.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_EDITED,
 	                                 g_param_spec_int64 ("edited",
 	                                                     "Edited", "The last time the document was edited.",
@@ -191,7 +191,7 @@ gdata_documents_entry_class_init (GDataDocumentsEntryClass *klass)
 	 * The last time the document was viewed.
 	 *
 	 * Since: 0.4.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_LAST_VIEWED,
 	                                 g_param_spec_int64 ("last-viewed",
 	                                                     "Last viewed", "The last time the document was viewed.",
@@ -204,7 +204,7 @@ gdata_documents_entry_class_init (GDataDocumentsEntryClass *klass)
 	 * Indicates whether the document entry writers can invite others to edit the document.
 	 *
 	 * Since: 0.4.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_WRITERS_CAN_INVITE,
 	                                 g_param_spec_boolean ("writers-can-invite",
 	                                                       "Writers can invite?", "Indicates whether writers can invite others to edit.",
@@ -218,7 +218,7 @@ gdata_documents_entry_class_init (GDataDocumentsEntryClass *klass)
 	 * appear in query results if the #GDataDocumentsQuery:show-deleted property is %TRUE.
 	 *
 	 * Since: 0.5.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_IS_DELETED,
 	                                 g_param_spec_boolean ("is-deleted",
 	                                                       "Deleted?", "Indicates whether the document entry has been deleted.",
@@ -257,7 +257,7 @@ gdata_documents_entry_class_init (GDataDocumentsEntryClass *klass)
 	 *
 	 * Since: 0.4.0
 	 * Deprecated: 0.11.0: This a substring of the #GDataDocumentsEntry:resource-id, which is more general and should be used instead.
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_DOCUMENT_ID,
 	                                 g_param_spec_string ("document-id",
 	                                                      "Document ID", "The document ID of the document.",
@@ -270,7 +270,7 @@ gdata_documents_entry_class_init (GDataDocumentsEntryClass *klass)
 	 * Indicates the author of the last modification.
 	 *
 	 * Since: 0.4.0
-	 **/
+	 */
 	g_object_class_install_property (gobject_class, PROP_LAST_MODIFIED_BY,
 	                                 g_param_spec_object ("last-modified-by",
 	                                                      "Last modified by", "Indicates the author of the last modification.",
@@ -292,6 +292,22 @@ gdata_documents_entry_class_init (GDataDocumentsEntryClass *klass)
 	                                                     "Quota used", "The amount of user quota the document is occupying.",
 	                                                     0, G_MAXINT64, 0,
 	                                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+
+	/**
+	 * GDataDocumentsEntry:file-size:
+	 *
+         * The size of the document. This is only set for non-document files.
+         * Standard formats, such as #GDataDocumentsText,
+         * #GDataDocumentsSpreadsheet and #GDataDocumentsFolder are not binary
+         * data and so have no size. Measured in bytes.
+	 *
+	 * Since: 0.17.7
+	 */
+	g_object_class_install_property (gobject_class, PROP_FILE_SIZE,
+	                                 g_param_spec_int64 ("file-size",
+	                                                     "File size", "The size of the document.",
+	                                                     0, G_MAXINT64, 0,
+	                                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 }
 
 static gboolean
@@ -376,7 +392,6 @@ gdata_documents_entry_finalize (GObject *object)
 {
 	GDataDocumentsEntryPrivate *priv = GDATA_DOCUMENTS_ENTRY (object)->priv;
 
-	g_free (priv->mime_type);
 	g_free (priv->resource_id);
 
 	/* Chain up to the parent class */
@@ -413,6 +428,9 @@ gdata_documents_entry_get_property (GObject *object, guint property_id, GValue *
 		case PROP_QUOTA_USED:
 			g_value_set_int64 (value, priv->quota_used);
 			break;
+		case PROP_FILE_SIZE:
+			g_value_set_int64 (value, priv->file_size);
+			break;
 		default:
 			/* We don't have any other property... */
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -430,6 +448,7 @@ gdata_documents_entry_set_property (GObject *object, guint property_id, const GV
 			gdata_documents_entry_set_writers_can_invite (self, g_value_get_boolean (value));
 			break;
 		case PROP_QUOTA_USED:
+		case PROP_FILE_SIZE:
 			/* Read only. */
 		default:
 			/* We don't have any other property... */
@@ -570,7 +589,9 @@ parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GEr
 	gboolean success = TRUE;
 	gchar *alternate_uri = NULL;
 	gchar *kind = NULL;
+	gchar *mime_type = NULL;
 	gchar *quota_used = NULL;
+	gchar *file_size = NULL;
 	gint64 published;
 	gint64 updated;
 
@@ -587,14 +608,10 @@ parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GEr
 
 		g_free (alternate_uri);
 		return success;
-	} else if (gdata_parser_string_from_json_member (reader, "mimeType", P_DEFAULT, &(priv->mime_type), &success, error) == TRUE) {
-		if (success && priv->mime_type != NULL && priv->mime_type[0] != '\0') {
-			GDataEntryClass *klass = GDATA_ENTRY_GET_CLASS (parsable);
-
-			category = gdata_category_new (klass->kind_term, "http://schemas.google.com/g/2005#kind", priv->mime_type);
-			gdata_entry_add_category (GDATA_ENTRY (parsable), category);
-			g_object_unref (category);
-		}
+	} else if (gdata_parser_string_from_json_member (reader, "mimeType", P_DEFAULT, &mime_type, &success, error) == TRUE) {
+		if (success)
+			gdata_documents_utils_add_content_type (GDATA_DOCUMENTS_ENTRY (parsable), mime_type);
+		g_free (mime_type);
 		return success;
 	} else if (gdata_parser_int64_time_from_json_member (reader, "lastViewedByMeDate", P_DEFAULT, &(priv->last_viewed), &success, error) == TRUE ||
 		   gdata_parser_string_from_json_member (reader, "kind", P_REQUIRED | P_NON_EMPTY, &kind, &success, error) == TRUE) {
@@ -620,6 +637,18 @@ parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GEr
 			priv->quota_used = (goffset) val;
 		g_free (quota_used);
 		return success;
+	} else if (gdata_parser_string_from_json_member (reader, "fileSize", P_DEFAULT, &file_size, &success, error) == TRUE) {
+		gchar *end_ptr;
+		guint64 val;
+
+		/* like 'quotaBytesUsed', 'fileSize' is also a string
+		 * in the JSON.
+		 */
+		val = g_ascii_strtoull (file_size, &end_ptr, 10);
+		if (*end_ptr == '\0')
+			priv->file_size = (goffset) val;
+		g_free (file_size);
+		return success;
 	} else if (gdata_parser_boolean_from_json_member (reader, "shared", P_DEFAULT, &shared, &success, error) == TRUE) {
 		if (success && shared) {
 			category = gdata_category_new ("http://schemas.google.com/g/2005/labels#shared", GDATA_CATEGORY_SCHEMA_LABELS, "shared");
@@ -838,25 +867,16 @@ get_json (GDataParsable *parsable, JsonBuilder *builder)
 	parent_folders_list = gdata_entry_look_up_links (GDATA_ENTRY (parsable), GDATA_LINK_PARENT);
 	for (i = parent_folders_list; i != NULL; i = i->next) {
 		GDataLink *_link = GDATA_LINK (i->data);
-		const gchar *uri;
-		gsize uri_prefix_len;
+		const gchar *id;
 
-		/* HACK: Extract the ID from the GDataLink:uri by removing the prefix. Ignore links which
-		 * don't have the prefix. */
-		uri = gdata_link_get_uri (_link);
-		uri_prefix_len = strlen (GDATA_DOCUMENTS_URI_PREFIX);
-		if (g_str_has_prefix (uri, GDATA_DOCUMENTS_URI_PREFIX)) {
-			const gchar *id;
-
-			id = uri + uri_prefix_len;
-			if (id[0] != '\0') {
-				json_builder_begin_object (builder);
-				json_builder_set_member_name (builder, "kind");
-				json_builder_add_string_value (builder, "drive#fileLink");
-				json_builder_set_member_name (builder, "id");
-				json_builder_add_string_value (builder, id);
-				json_builder_end_object (builder);
-			}
+		id = gdata_documents_utils_get_id_from_link (_link);
+		if (id != NULL) {
+			json_builder_begin_object (builder);
+			json_builder_set_member_name (builder, "kind");
+			json_builder_add_string_value (builder, "drive#fileLink");
+			json_builder_set_member_name (builder, "id");
+			json_builder_add_string_value (builder, id);
+			json_builder_end_object (builder);
 		}
 	}
 
@@ -891,7 +911,7 @@ get_entry_uri (const gchar *id)
  *
  * Since: 0.4.0
  * Deprecated: 0.17.0: Use gdata_entry_get_updated() instead. See #GDataDocumentsEntry:edited.
- **/
+ */
 gint64
 gdata_documents_entry_get_edited (GDataDocumentsEntry *self)
 {
@@ -908,7 +928,7 @@ gdata_documents_entry_get_edited (GDataDocumentsEntry *self)
  * Return value: the UNIX timestamp for the time the document was last viewed, or <code class="literal">-1</code>
  *
  * Since: 0.4.0
- **/
+ */
 gint64
 gdata_documents_entry_get_last_viewed (GDataDocumentsEntry *self)
 {
@@ -931,7 +951,7 @@ gdata_documents_entry_get_last_viewed (GDataDocumentsEntry *self)
  * Return value: the folder hierarchy path containing the document, or %NULL; free with g_free()
  *
  * Since: 0.4.0
- **/
+ */
 gchar *
 gdata_documents_entry_get_path (GDataDocumentsEntry *self)
 {
@@ -997,7 +1017,7 @@ gdata_documents_entry_get_path (GDataDocumentsEntry *self)
  *
  * Since: 0.4.0
  * Deprecated: 0.11.0: Use gdata_documents_entry_get_resource_id() instead. See #GDataDocumentsEntry:document-id.
- **/
+ */
 const gchar *
 gdata_documents_entry_get_document_id (GDataDocumentsEntry *self )
 {
@@ -1030,7 +1050,7 @@ gdata_documents_entry_get_resource_id (GDataDocumentsEntry *self)
  * Sets the #GDataDocumentsEntry:writers-can-invite property to @writers_can_invite.
  *
  * Since: 0.4.0
- **/
+ */
 void
 gdata_documents_entry_set_writers_can_invite (GDataDocumentsEntry *self, gboolean writers_can_invite)
 {
@@ -1048,7 +1068,7 @@ gdata_documents_entry_set_writers_can_invite (GDataDocumentsEntry *self, gboolea
  * Return value: %TRUE if writers can invite other people to edit the document, %FALSE otherwise
  *
  * Since: 0.4.0
- **/
+ */
 gboolean
 gdata_documents_entry_writers_can_invite (GDataDocumentsEntry *self)
 {
@@ -1065,7 +1085,7 @@ gdata_documents_entry_writers_can_invite (GDataDocumentsEntry *self)
  * Return value: (transfer none): the author who last modified the document
  *
  * Since: 0.4.0
- **/
+ */
 GDataAuthor *
 gdata_documents_entry_get_last_modified_by (GDataDocumentsEntry *self)
 {
@@ -1091,6 +1111,24 @@ gdata_documents_entry_get_quota_used (GDataDocumentsEntry *self)
 	return self->priv->quota_used;
 }
 
+/**
+ * gdata_documents_entry_get_file_size:
+ * @self: a #GDataDocumentsEntry
+ *
+ * Gets the #GDataDocumentsEntry:file-size property.
+ *
+ * Return value: the size of the document in bytes
+ *
+ * Since: 0.17.7
+ */
+goffset
+gdata_documents_entry_get_file_size (GDataDocumentsEntry *self)
+{
+	g_return_val_if_fail (GDATA_IS_DOCUMENTS_ENTRY (self), 0);
+
+	return self->priv->file_size;
+}
+
 /**
  * gdata_documents_entry_is_deleted:
  * @self: a #GDataDocumentsEntry
@@ -1100,7 +1138,7 @@ gdata_documents_entry_get_quota_used (GDataDocumentsEntry *self)
  * Return value: %TRUE if the document has been deleted, %FALSE otherwise
  *
  * Since: 0.5.0
- **/
+ */
 gboolean
 gdata_documents_entry_is_deleted (GDataDocumentsEntry *self)
 {
