@@ -40,6 +40,7 @@
 #include "gdata-tasks-query.h"
 #include "gdata-query.h"
 #include "gdata-parser.h"
+#include "gdata-private.h"
 
 static void gdata_tasks_query_finalize (GObject *object);
 static void gdata_tasks_query_get_property (GObject *object, guint property_id, GValue *value, GParamSpec *pspec);
@@ -185,6 +186,9 @@ gdata_tasks_query_init (GDataTasksQuery *self)
 	self->priv->completed_max = -1;
 	self->priv->due_min = -1;
 	self->priv->due_max = -1;
+
+	_gdata_query_set_pagination_type (GDATA_QUERY (self),
+	                                  GDATA_QUERY_PAGINATION_TOKENS);
 }
 
 static void
@@ -267,6 +271,11 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 {
 	GDataTasksQueryPrivate *priv = GDATA_TASKS_QUERY (self)->priv;
 
+	/* Chain up to the parent class. This adds a load of irrelevant query
+	 * parameters, but they’re harmless. Importantly, it adds pagination
+	 * support. */
+	GDATA_QUERY_CLASS (gdata_tasks_query_parent_class)->get_query_uri (self, feed_uri, query_uri, params_started);
+
 	#define APPEND_SEP g_string_append_c (query_uri, (*params_started == FALSE) ? '?' : '&'); *params_started = TRUE;
 
 	if (gdata_query_get_max_results (GDATA_QUERY (self)) > 0) {
@@ -279,7 +288,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 
 		APPEND_SEP
 		g_string_append (query_uri, "updatedMin=");
-		updated_min = gdata_parser_int64_to_iso8601 (gdata_query_get_updated_min (GDATA_QUERY (self)));
+		updated_min = gdata_parser_int64_to_iso8601_numeric_timezone (gdata_query_get_updated_min (GDATA_QUERY (self)));
 		g_string_append (query_uri, updated_min);
 		g_free (updated_min);
 	}
@@ -289,7 +298,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 
 		APPEND_SEP
 		g_string_append (query_uri, "completedMin=");
-		completed_min = gdata_parser_int64_to_iso8601 (priv->completed_min);
+		completed_min = gdata_parser_int64_to_iso8601_numeric_timezone (priv->completed_min);
 		g_string_append (query_uri, completed_min);
 		g_free (completed_min);
 	}
@@ -299,7 +308,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 
 		APPEND_SEP
 		g_string_append (query_uri, "completedMax=");
-		completed_max = gdata_parser_int64_to_iso8601 (priv->completed_max);
+		completed_max = gdata_parser_int64_to_iso8601_numeric_timezone (priv->completed_max);
 		g_string_append (query_uri, completed_max);
 		g_free (completed_max);
 	}
@@ -309,7 +318,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 
 		APPEND_SEP
 		g_string_append (query_uri, "dueMin=");
-		due_min = gdata_parser_int64_to_iso8601 (priv->due_min);
+		due_min = gdata_parser_int64_to_iso8601_numeric_timezone (priv->due_min);
 		g_string_append (query_uri, due_min);
 		g_free (due_min);
 	}
@@ -319,7 +328,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 
 		APPEND_SEP
 		g_string_append (query_uri, "dueMax=");
-		due_max = gdata_parser_int64_to_iso8601 (priv->due_max);
+		due_max = gdata_parser_int64_to_iso8601_numeric_timezone (priv->due_max);
 		g_string_append (query_uri, due_max);
 		g_free (due_max);
 	}
@@ -345,10 +354,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 		g_string_append (query_uri, "showHidden=false");
 	}
 
-	/* We don't chain up with parent class get_query_uri because it uses
-	 *  GData protocol parameters and they aren't compatible with newest API family
-	 */
-	 #undef APPEND_SEP
+	#undef APPEND_SEP
 }
 
 /**
