@@ -55,10 +55,6 @@ gdata_test_init (int argc, char **argv)
 
 	setlocale (LC_ALL, "");
 
-#if !GLIB_CHECK_VERSION (2, 35, 0)
-	g_type_init ();
-#endif
-
 	/* Parse the custom options */
 	for (i = 1; i < argc; i++) {
 		if (strcmp ("--no-interactive", argv[i]) == 0 || strcmp ("-ni", argv[i]) == 0) {
@@ -886,7 +882,7 @@ output_commented_lines (const gchar *message)
 {
 	const gchar *i, *next_newline;
 
-	for (i = message; i != NULL && i != '\0'; i = next_newline) {
+	for (i = message; i != NULL && *i != '\0'; i = next_newline) {
 		gchar *line;
 
 		next_newline = strchr (i, '\n');
